@@ -208,7 +208,8 @@ enum {
 	ESLURM_INVALID_JOB_DEFAULTS,
 	ESLURM_RESERVATION_MAINT,
 	ESLURM_INVALID_GRES_TYPE,
-	ESLURM_REBOOT_IN_PROGRESS,
+	ESLURM_REBOOT_IN_PROGRESS =			2120,
+	ESLURM_MULTI_KNL_CONSTRAINT,
 
 	/* switch specific error codes, specific values defined in plugin module */
 	ESLURM_SWITCH_MIN = 3000,
