@@ -8,11 +8,11 @@
  *  Written by Morris Jette <jette1@llnl.gov>.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -28,13 +28,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -55,7 +55,6 @@ void slurm_init_job_desc_msg(job_desc_msg_t * job_desc_msg)
 {
 	memset(job_desc_msg, 0, sizeof(job_desc_msg_t));
 	job_desc_msg->alloc_sid		= NO_VAL;
-	job_desc_msg->conn_type[0]	= NO_VAL16;
 	job_desc_msg->contiguous	= NO_VAL16;
 	job_desc_msg->core_spec		= NO_VAL16;
 	job_desc_msg->cores_per_socket	= NO_VAL16;
@@ -65,7 +64,6 @@ void slurm_init_job_desc_msg(job_desc_msg_t * job_desc_msg)
 	job_desc_msg->cpu_freq_gov	= NO_VAL;
 	job_desc_msg->cpus_per_task	= NO_VAL16;
 	job_desc_msg->delay_boot	= NO_VAL;
-	job_desc_msg->geometry[0]       = NO_VAL16;
 	job_desc_msg->group_id		= NO_VAL;
 	job_desc_msg->job_id		= NO_VAL;
 	job_desc_msg->kill_on_node_fail = NO_VAL16;
@@ -88,7 +86,6 @@ void slurm_init_job_desc_msg(job_desc_msg_t * job_desc_msg)
 	job_desc_msg->reboot		= NO_VAL16;
 	job_desc_msg->requeue		= NO_VAL16;
 	job_desc_msg->req_switch	= NO_VAL;
-	job_desc_msg->rotate		= NO_VAL16;
 	job_desc_msg->shared		= NO_VAL16;
 	job_desc_msg->sockets_per_node	= NO_VAL16;
 	job_desc_msg->task_dist		= NO_VAL;
@@ -174,19 +171,6 @@ void slurm_init_update_front_end_msg (update_front_end_msg_t *
 	update_front_end_msg->node_state = NO_VAL;
 }
 
-/*
- * slurm_init_update_block_msg - initialize block update message
- * OUT update_block_msg - user defined block descriptor
- */
-void slurm_init_update_block_msg (update_block_msg_t *update_block_msg)
-{
-	memset(update_block_msg, 0, sizeof(update_block_msg_t));
-	update_block_msg->conn_type[0] = NO_VAL16;
-	update_block_msg->cnode_cnt = NO_VAL;
-	update_block_msg->node_use = NO_VAL16;
-	update_block_msg->state = NO_VAL16;
-}
-
 /*
  * slurm_init_trigger_msg - initialize trigger clear/update message
  * OUT trigger_info_msg - user defined trigger descriptor
