@@ -8,11 +8,11 @@
  *  Written by Morris Jette <jette1@llnl.gov> et. al.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -28,13 +28,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -49,8 +49,7 @@
 #include "src/common/forward.h"
 #include "src/common/xmalloc.h"
 
-static int _send_message_controller (	enum controller_id dest,
-					slurm_msg_t *request_msg );
+static int _send_message_controller(int dest, slurm_msg_t *req);
 
 /*
  * slurm_reconfigure - issue RPC to have Slurm controller (slurmctld)
@@ -79,44 +78,35 @@ slurm_reconfigure (void)
 
 /*
  * slurm_ping - issue RPC to have Slurm controller (slurmctld)
- * IN controller - 1==primary controller, 2==secondary controller
+ * IN dest - controller to contact (0=primary, 1=backup, 2=backup2, etc.)
  * RET 0 or a slurm error code
  */
-int
-slurm_ping (int primary)
+extern int slurm_ping(int dest)
 {
 	int rc ;
 	slurm_msg_t request_msg ;
 
 	slurm_msg_t_init(&request_msg);
 	request_msg.msg_type = REQUEST_PING ;
-
-	if (primary == 1)
-		rc = _send_message_controller ( PRIMARY_CONTROLLER,
-						&request_msg );
-	else if (primary == 2)
-		rc = _send_message_controller ( SECONDARY_CONTROLLER,
-						&request_msg );
-	else
-		rc = SLURM_ERROR;
+	rc = _send_message_controller(dest, &request_msg);
 
 	return rc;
 }
 
 /*
  * slurm_shutdown - issue RPC to have Slurm controller (slurmctld)
- *	cease operations, both the primary and backup controller
+ *	cease operations, both the primary and all backup controllers
  *	are shutdown.
  * IN options - 0: all slurm daemons are shutdown
  *              1: slurmctld generates a core file
  *              2: only the slurmctld is shutdown (no core file)
  * RET 0 or a slurm error code
  */
-int
-slurm_shutdown (uint16_t options)
+extern int slurm_shutdown(uint16_t options)
 {
 	slurm_msg_t req_msg;
 	shutdown_msg_t shutdown_msg;
+	int i;
 
 	slurm_msg_t_init(&req_msg);
 	shutdown_msg.options = options;
@@ -124,55 +114,62 @@ slurm_shutdown (uint16_t options)
 	req_msg.data         = &shutdown_msg;
 
 	/*
-	 * Explicity send the message to both primary
-	 *   and backup controllers
+	 * Explicity send the message to both primary and backup controllers
 	 */
-	if (!working_cluster_rec)
-		(void) _send_message_controller(SECONDARY_CONTROLLER, &req_msg);
-	return _send_message_controller(PRIMARY_CONTROLLER,   &req_msg);
+	if (!working_cluster_rec) {
+		uint32_t control_cnt = slurm_get_control_cnt();
+		for (i = 1; i < control_cnt; i++)
+			(void) _send_message_controller(i, &req_msg);
+	}
+	return _send_message_controller(0, &req_msg);
 }
 
 /*
- * slurm_takeover - issue RPC to have Slurm backup controller take over the
+ * slurm_takeover - issue RPC to have a Slurm backup controller take over the
  *                  primary controller. REQUEST_CONTROL is sent by the backup
  *                  to the primary controller to take control
+ * backup_inx IN - Index of BackupController to assume controller (typically 1)
  * RET 0 or a slurm error code
  */
-int
-slurm_takeover ( void )
+extern int slurm_takeover(int backup_inx)
 {
 	slurm_msg_t req_msg;
 
 	slurm_msg_t_init(&req_msg);
 	req_msg.msg_type     = REQUEST_TAKEOVER;
-
-	return _send_message_controller(SECONDARY_CONTROLLER, &req_msg);
+	if (backup_inx < 1)
+		return SLURMCTLD_COMMUNICATIONS_CONNECTION_ERROR;
+	return _send_message_controller(backup_inx, &req_msg);
 }
 
-int
-_send_message_controller (enum controller_id dest, slurm_msg_t *req)
+static int _send_message_controller(int dest, slurm_msg_t *req)
 {
 	int rc = SLURM_PROTOCOL_SUCCESS;
 	int fd = -1;
 	slurm_msg_t resp_msg;
 
-	/* always going to one node (primary or backup per value of "dest") */
-	if ((fd = slurm_open_controller_conn_spec(dest,working_cluster_rec)) <0)
+	/*
+	 * always communicate with a single node (primary or some backup per
+	 * value of "dest")
+	 */
+	if ((fd = slurm_open_controller_conn_spec(dest,
+						  working_cluster_rec)) < 0) {
 		slurm_seterrno_ret(SLURMCTLD_COMMUNICATIONS_CONNECTION_ERROR);
+	}
 
 	if (slurm_send_node_msg(fd, req) < 0) {
-		slurm_shutdown_msg_conn(fd);
+		close(fd);
 		slurm_seterrno_ret(SLURMCTLD_COMMUNICATIONS_SEND_ERROR);
 	}
 	slurm_msg_t_init(&resp_msg);
 
 	if ((rc = slurm_receive_msg(fd, &resp_msg, 0)) != 0) {
 		slurm_free_msg_members(&resp_msg);
-		slurm_shutdown_msg_conn(fd);
+		close(fd);
 		return SLURMCTLD_COMMUNICATIONS_RECEIVE_ERROR;
 	}
 
-	if (slurm_shutdown_msg_conn(fd) != SLURM_SUCCESS)
+	if (close(fd) != SLURM_SUCCESS)
 		rc = SLURMCTLD_COMMUNICATIONS_SHUTDOWN_ERROR;
 	else if (resp_msg.msg_type != RESPONSE_SLURM_RC)
 		rc = SLURM_UNEXPECTED_MSG_ERROR;
