@@ -7,11 +7,11 @@
  *  Written by Danny Auble <da@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *****************************************************************************
  * NOTE: When using lock_slurmctld() and assoc_mgr_lock(), always call
@@ -71,13 +71,6 @@ typedef struct {
 	lock_level_t wckey;
 } assoc_mgr_lock_t;
 
-/* Interval lock structure
- * we actually use the count for each data type, see macros below
- *   (assoc_mgr_lock_datatype_t * 4 + 0) = read_lock        read locks in use
- *   (assoc_mgr_lock_datatype_t * 4 + 1) = write_lock       write locks in use
- *   (assoc_mgr_lock_datatype_t * 4 + 2) = write_wait_lock  write locks pending
- *   (assoc_mgr_lock_datatype_t * 4 + 3) = write_cnt_lock   write lock count
- */
 typedef enum {
 	ASSOC_LOCK,
 	FILE_LOCK,
@@ -89,18 +82,16 @@ typedef enum {
 	ASSOC_MGR_ENTITY_COUNT
 } assoc_mgr_lock_datatype_t;
 
-typedef struct {
-	int entity[ASSOC_MGR_ENTITY_COUNT * 4];
-} assoc_mgr_lock_flags_t;
-
 typedef struct {
  	uint16_t cache_level;
 	uint16_t enforce;
+	uint16_t *running_cache;
 	void (*add_license_notify) (slurmdb_res_rec_t *rec);
 	void (*resize_qos_notify) (void);
 	void (*remove_assoc_notify) (slurmdb_assoc_rec_t *rec);
 	void (*remove_license_notify) (slurmdb_res_rec_t *rec);
 	void (*remove_qos_notify) (slurmdb_qos_rec_t *rec);
+	char **state_save_location;
 	void (*sync_license_notify) (List clus_res_list);
 	void (*update_assoc_notify) (slurmdb_assoc_rec_t *rec);
 	void (*update_cluster_tres) (void);
@@ -129,10 +120,17 @@ extern uint32_t g_tres_count; /* Number of TRES from the database
 
 extern int assoc_mgr_init(void *db_conn, assoc_init_args_t *args,
 			  int db_conn_errno);
-extern int assoc_mgr_fini(char *state_save_location);
+extern int assoc_mgr_fini(bool save_state);
 extern void assoc_mgr_lock(assoc_mgr_lock_t *locks);
 extern void assoc_mgr_unlock(assoc_mgr_lock_t *locks);
 
+#ifndef NDEBUG
+extern bool verify_assoc_lock(assoc_mgr_lock_datatype_t datatype, lock_level_t level);
+#endif
+
+/* ran after a new tres_list is given */
+extern int assoc_mgr_post_tres_list(List new_list);
+
 /*
  * get info from the storage
  * IN:  assoc - slurmdb_assoc_rec_t with at least cluster and
@@ -189,7 +187,7 @@ extern int assoc_mgr_fill_in_tres(void *db_conn,
  *                      DO NOT FREE.
  * IN: locked - If you plan on using assoc_pptr after this function
  *              you need to have an assoc_mgr_lock_t READ_LOCK for
- *              associations while you use it before and after the
+ *              associations and users while you use it before and after the
  *              return.  This is not required if using the assoc for
  *              non-pointer portions.
  * RET: SLURM_SUCCESS on success, else SLURM_ERROR
@@ -208,11 +206,16 @@ extern int assoc_mgr_fill_in_assoc(void *db_conn,
  * IN/OUT: user_pptr - if non-NULL then return a pointer to the
  *		       slurmdb_user record in cache on success
  *                     DO NOT FREE.
+ * IN: locked - If you plan on using user_pptr outside
+ *              this function you need to have an assoc_mgr_lock_t
+ *              READ_LOCK for User while you use it before and after the
+ *              return.  This is not required if using the assoc for
+ *              non-pointer portions.
  * RET: SLURM_SUCCESS on success SLURM_ERROR else
  */
 extern int assoc_mgr_fill_in_user(void *db_conn, slurmdb_user_rec_t *user,
 				  int enforce,
-				  slurmdb_user_rec_t **user_pptr);
+				  slurmdb_user_rec_t **user_pptr, bool locked);
 
 /*
  * get info from the storage
@@ -238,12 +241,18 @@ extern int assoc_mgr_fill_in_qos(void *db_conn, slurmdb_qos_rec_t *qos,
  * IN: enforce - return an error if no such wckey exists
  * IN/OUT: wckey_pptr - if non-NULL then return a pointer to the
  *			slurmdb_wckey record in cache on success
+ * IN: locked - If you plan on using wckey_pptr outside
+ *              this function you need to have an assoc_mgr_lock_t
+ *              READ_LOCK for WCKey and Users while you use it before and after
+ *              the return.  This is not required if using the assoc for
+ *              non-pointer portions.
  * RET: SLURM_SUCCESS on success, else SLURM_ERROR
  */
 extern int assoc_mgr_fill_in_wckey(void *db_conn,
 				   slurmdb_wckey_rec_t *wckey,
 				   int enforce,
-				   slurmdb_wckey_rec_t **wckey_pptr);
+				   slurmdb_wckey_rec_t **wckey_pptr,
+				   bool locked);
 
 /*
  * get admin_level of uid
@@ -394,23 +403,28 @@ extern void assoc_mgr_remove_qos_usage(slurmdb_qos_rec_t *qos);
  * Dump the state information of the association mgr just in case the
  * database isn't up next time we run.
  */
-extern int dump_assoc_mgr_state(char *state_save_location);
+extern int dump_assoc_mgr_state(void);
 
 /*
  * Read in the past usage for associations.
  */
-extern int load_assoc_usage(char *state_save_location);
+extern int load_assoc_usage(void);
 
 /*
  * Read in the past usage for qos.
  */
-extern int load_qos_usage(char *state_save_location);
+extern int load_qos_usage(void);
+
+/*
+ * Read in the past tres list.
+ */
+extern int load_assoc_mgr_last_tres(void);
 
 /*
  * Read in the information of the association mgr if the database
  * isn't up when starting.
  */
-extern int load_assoc_mgr_state(char *state_save_location);
+extern int load_assoc_mgr_state(bool only_tres);
 
 /*
  * Refresh the lists if when running_cache is set this will load new
@@ -489,4 +503,15 @@ extern void assoc_mgr_get_default_qos_info(
  */
 extern double assoc_mgr_tres_weighted(uint64_t *tres_cnt, double *weights,
 				      uint16_t flags, bool locked);
+
+/* Get TRES's old position.
+ * IN: cur_pos - the current position in the tres array.
+ */
+extern int assoc_mgr_get_old_tres_pos(int cur_pos);
+
+/* Test whether the tres positions have changed since last reading the tres
+ * list.
+ */
+extern int assoc_mgr_tres_pos_changed();
+
 #endif /* _SLURM_ASSOC_MGR_H */
