@@ -85,7 +85,6 @@ typedef enum {
 	LOG_LEVEL_DEBUG3,
 	LOG_LEVEL_DEBUG4,
 	LOG_LEVEL_DEBUG5,
-	LOG_LEVEL_SCHED,
 	LOG_LEVEL_END
 }	log_level_t;
 
@@ -94,11 +93,11 @@ typedef enum {
  * log options: Each of stderr, syslog, and logfile can have a different level
  */
 typedef struct {
-	log_level_t stderr_level;   /* max level to log to stderr         */
-	log_level_t syslog_level;   /* max level to log to syslog         */
-	log_level_t logfile_level;  /* max level to log to logfile        */
-	unsigned    prefix_level:1; /* prefix level (e.g. "debug: ") if 1 */
-	unsigned    buffered:1;     /* Use internal buffer to never block */
+	log_level_t stderr_level;   /* max level to log to stderr            */
+	log_level_t syslog_level;   /* max level to log to syslog            */
+	log_level_t logfile_level;  /* max level to log to logfile           */
+	bool prefix_level;          /* prefix level (e.g. "debug: ") if true */
+	bool buffered;              /* use internal buffer to never block    */
 } 	log_options_t;
 
 extern char *slurm_prog_name;
@@ -148,9 +147,6 @@ int log_init(char *argv0, log_options_t opts,
 int sched_log_init(char *argv0, log_options_t opts, log_facility_t fac,
 		   char *logfile);
 
-/* Write to scheduler log */
-void schedlog(const char *fmt, ...);
-
 /* reinitialize log module.
  * Keep same log options as previously initialized log, but reinit mutex
  * that protects the log. This call is needed after a fork() in a threaded
@@ -246,6 +242,9 @@ extern int get_log_level(void);
  * args are printf style with the following exceptions:
  * %m expands to strerror(errno)
  * %M expand to time stamp, format is configuration dependent
+ * %pJ expands to "JobId=XXXX" for the given job_ptr, with the appropriate
+ *     format for job arrays and hetjob components.
+ * %pS expands to "JobId=XXXX StepId=YYYY" for a given step_ptr.
  * %t expands to strftime("%x %X") [ locally preferred short date/time ]
  * %T expands to rfc2822 date time  [ "dd, Mon yyyy hh:mm:ss GMT offset" ]
  */
@@ -268,4 +267,15 @@ void	debug3(const char *, ...) __attribute__ ((format (printf, 1, 2)));
 void	debug4(const char *, ...) __attribute__ ((format (printf, 1, 2)));
 void	debug5(const char *, ...) __attribute__ ((format (printf, 1, 2)));
 
+/*
+ * Like above logging messages, but prepend "sched: " to the log entry
+ * and route the message into the sched_log if enabled.
+ */
+int	sched_error(const char *, ...) __attribute__ ((format (printf, 1, 2)));
+void	sched_info(const char *, ...) __attribute__ ((format (printf, 1, 2)));
+void	sched_verbose(const char *, ...) __attribute__ ((format (printf, 1, 2)));
+void	sched_debug(const char *, ...) __attribute__ ((format (printf, 1, 2)));
+void	sched_debug2(const char *, ...) __attribute__ ((format (printf, 1, 2)));
+void	sched_debug3(const char *, ...) __attribute__ ((format (printf, 1, 2)));
+
 #endif /* !_LOG_H */
