@@ -6,11 +6,11 @@
  *  Written by Mark Grondona <grondo1@llnl.gov>.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -26,13 +26,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -49,6 +49,8 @@
 #include "src/common/xmalloc.h"
 #include "src/common/xstring.h"
 
+#define _DEBUG 0
+
 /*
  * WARNING:  Do not change the order of these fields or add additional
  * fields at the beginning of the structure.  If you do, MPI plugins
@@ -82,6 +84,83 @@ static plugin_context_t *g_context = NULL;
 static pthread_mutex_t      context_lock = PTHREAD_MUTEX_INITIALIZER;
 static bool init_run = false;
 
+#if _DEBUG
+/* Debugging information is invaluable to debug heterogeneous step support */
+static inline void _log_env(char **env)
+{
+#if _DEBUG > 1
+	int i;
+
+	if (!env)
+		return;
+
+	for (i = 0; env[i]; i++)
+		info("%s", env[i]);
+#endif
+}
+
+static void _log_step_rec(const stepd_step_rec_t *job)
+{
+	int i;
+
+	info("STEPD_STEP_REC");
+	info("job_id:%u step_id:%u", job->jobid, job->stepid);
+	info("ntasks:%u nnodes:%u node_id:%u", job->ntasks, job->nnodes,
+	     job->nodeid);
+	info("node_tasks:%u", job->node_tasks);
+	for (i = 0; i < job->node_tasks; i ++)
+		info("gtid[%d]:%u", i, job->task[i]->gtid);
+	for (i = 0; i < job->nnodes; i++)
+		info("task_cnts[%d]:%u", i, job->task_cnts[i]);
+
+	if ((job->pack_jobid != 0) && (job->pack_jobid != NO_VAL)) {
+		info("pack_job_id:%u step_id:%u", job->pack_jobid, job->stepid);
+		info("pack_ntasks:%u pack_nnodes:%u", job->pack_ntasks,
+		     job->pack_nnodes);
+		info("pack_node_offset:%u pack_task_offset:%u",
+		     job->node_offset, job->pack_task_offset);
+		for (i = 0; i < job->pack_nnodes; i++)
+			info("pack_task_cnts[%d]:%u", i,job->pack_task_cnts[i]);
+		info("pack_node_list:%s", job->pack_node_list);
+	}
+}
+
+static void _log_mpi_rec(const mpi_plugin_client_info_t *job)
+{
+	slurm_step_layout_t *layout = job->step_layout;
+	int i, j;
+
+	info("MPI_PLUGIN_CLIENT_INFO");
+	info("job_id:%u step_id:%u", job->jobid, job->stepid);
+	if ((job->pack_jobid != 0) && (job->pack_jobid != NO_VAL)) {
+		info("pack_job_id:%u step_id:%u", job->pack_jobid, job->stepid);
+	}
+	if (layout) {
+		info("node_cnt:%u task_cnt:%u", layout->node_cnt,
+		     layout->task_cnt);
+		info("node_list:%s", layout->node_list);
+		info("plane_size:%u task_dist:%u", layout->plane_size,
+		     layout->task_dist);
+		for (i = 0; i < layout->node_cnt; i++) {
+			info("tasks[%d]:%u", i, layout->tasks[i]);
+			for (j = 0; j < layout->tasks[i]; j++) {
+				info("tids[%d][%d]:%u", i, j,
+				     layout->tids[i][j]);
+			}
+		}
+	}
+}
+
+static void _log_task_rec(const mpi_plugin_task_info_t *job)
+{
+	info("MPI_PLUGIN_TASK_INFO");
+	info("job_id:%u step_id:%u", job->jobid, job->stepid);
+	info("nnodes:%u node_id:%u", job->nnodes, job->nodeid);
+	info("ntasks:%u local_tasks:%u", job->ntasks, job->ltasks);
+	info("global_task_id:%u local_task_id:%u", job->gtaskid, job->ltaskid);
+}
+#endif
+
 int _mpi_init (char *mpi_type)
 {
 	int retval = SLURM_SUCCESS;
@@ -149,7 +228,12 @@ int mpi_hook_slurmstepd_init (char ***env)
 {
 	char *mpi_type = getenvp (*env, "SLURM_MPI_TYPE");
 
+#if _DEBUG
+	info("IN %s mpi_type:%s", __func__, mpi_type);
+	_log_env(*env);
+#else
 	debug("mpi type = %s", mpi_type);
+#endif
 
 	if (_mpi_init(mpi_type) == SLURM_ERROR)
 		return SLURM_ERROR;
@@ -162,6 +246,12 @@ int mpi_hook_slurmstepd_init (char ***env)
 
 int mpi_hook_slurmstepd_prefork (const stepd_step_rec_t *job, char ***env)
 {
+#if _DEBUG
+	info("IN %s", __func__);
+	_log_env(*env);
+	_log_step_rec(job);
+#endif
+
 	if (mpi_hook_slurmstepd_init(env) == SLURM_ERROR)
 		return SLURM_ERROR;
 
@@ -170,6 +260,12 @@ int mpi_hook_slurmstepd_prefork (const stepd_step_rec_t *job, char ***env)
 
 int mpi_hook_slurmstepd_task (const mpi_plugin_task_info_t *job, char ***env)
 {
+#if _DEBUG
+	info("IN %s", __func__);
+	_log_task_rec(job);
+	_log_env(*env);
+#endif
+
 	if (mpi_hook_slurmstepd_init(env) == SLURM_ERROR)
 		return SLURM_ERROR;
 
@@ -178,7 +274,11 @@ int mpi_hook_slurmstepd_task (const mpi_plugin_task_info_t *job, char ***env)
 
 int mpi_hook_client_init (char *mpi_type)
 {
+#if _DEBUG
+	info("IN %s mpi_type:%s", __func__, mpi_type);
+#else
 	debug("mpi type = %s", mpi_type);
+#endif
 
 	if (_mpi_init(mpi_type) == SLURM_ERROR)
 		return SLURM_ERROR;
@@ -189,14 +289,29 @@ int mpi_hook_client_init (char *mpi_type)
 mpi_plugin_client_state_t *
 mpi_hook_client_prelaunch(const mpi_plugin_client_info_t *job, char ***env)
 {
+	mpi_plugin_client_state_t *rc;
+#if _DEBUG
+	info("IN %s", __func__);
+	_log_env(*env);
+	_log_mpi_rec(job);
+#endif
+
 	if (_mpi_init(NULL) < 0)
 		return NULL;
 
-	return (*(ops.client_prelaunch))(job, env);
+	rc = (*(ops.client_prelaunch))(job, env);
+#if _DEBUG
+	_log_env(*env);
+#endif
+	return rc;
 }
 
 int mpi_hook_client_fini (mpi_plugin_client_state_t *state)
 {
+#if _DEBUG
+	info("IN %s", __func__);
+#endif
+
 	if (_mpi_init(NULL) < 0)
 		return SLURM_ERROR;
 
@@ -214,5 +329,3 @@ int mpi_fini (void)
 	rc = plugin_context_destroy(g_context);
 	return rc;
 }
-
-
