@@ -9,11 +9,11 @@
  *             Morris Jette <jette1@llnl.gov>, et. al.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -29,21 +29,27 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \****************************************************************************/
 
+#define _GNU_SOURCE
+
 #include <errno.h>
+#include <fcntl.h>
 #include <inttypes.h>
 #include <netinet/in.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/mman.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 #include <time.h>
 
 #include "slurm/slurm_errno.h"
@@ -56,11 +62,16 @@
 #include "src/common/xassert.h"
 #include "src/slurmdbd/read_config.h"
 
+#define MAX_ARRAY_LEN_SMALL	10000
+#define MAX_ARRAY_LEN_MEDIUM	1000000
+#define MAX_ARRAY_LEN_LARGE	10000000
+
 /*
  * Define slurm-specific aliases for use by plugins, see slurm_xlator.h
  * for details.
  */
 strong_alias(create_buf,	slurm_create_buf);
+strong_alias(create_mmap_buf,	slurm_create_mmap_buf);
 strong_alias(free_buf,		slurm_free_buf);
 strong_alias(grow_buf,		slurm_grow_buf);
 strong_alias(init_buf,		slurm_init_buf);
@@ -113,23 +124,72 @@ Buf create_buf(char *data, uint32_t size)
 	my_buf->size = size;
 	my_buf->processed = 0;
 	my_buf->head = data;
+	my_buf->mmaped = false;
 
 	return my_buf;
 }
 
+/*
+ * create_mmap_buf - create an mmap()'d read-only buffer from
+ * the supplied file.
+ */
+Buf create_mmap_buf(char *file)
+{
+	Buf my_buf;
+	int fd;
+	struct stat f_stat;
+	void *data;
+
+	if ((fd = open(file, O_RDONLY | O_CLOEXEC)) < 0) {
+		debug("%s: Failed to open file `%s`, %m", __func__, file);
+		return NULL;
+	}
+
+	if (fstat(fd, &f_stat)) {
+		debug("%s: Failed to fstat file `%s`, %m", __func__, file);
+		close(fd);
+		return NULL;
+	}
+
+	data = mmap(NULL, f_stat.st_size, PROT_READ, MAP_SHARED, fd, 0);
+	close(fd);
+	if (data == MAP_FAILED) {
+		debug("%s: Failed to mmap file `%s`, %m", __func__, file);
+		return NULL;
+	}
+
+	my_buf = xmalloc_nz(sizeof(struct slurm_buf));
+	my_buf->magic = BUF_MAGIC;
+	my_buf->size = f_stat.st_size;
+	my_buf->processed = 0;
+	my_buf->head = data;
+	my_buf->mmaped = true;
+
+	debug3("%s: loaded file `%s` as Buf", __func__, file);
+
+	return my_buf;
+}
+
+
 /* free_buf - release memory associated with a given buffer */
 void free_buf(Buf my_buf)
 {
 	if (!my_buf)
 		return;
 	assert(my_buf->magic == BUF_MAGIC);
-	xfree(my_buf->head);
+	if (my_buf->mmaped)
+		munmap(my_buf->head, my_buf->size);
+	else
+		xfree(my_buf->head);
+
 	xfree(my_buf);
 }
 
 /* Grow a buffer by the specified amount */
 void grow_buf (Buf buffer, uint32_t size)
 {
+	if (buffer->mmaped)
+		fatal_abort("attempt to grow mmap()'d buffer not supported");
 	if ((buffer->size + size) > MAX_BUF_SIZE) {
 		error("%s: Buffer size limit exceeded (%u > %u)",
 		      __func__, (buffer->size + size), MAX_BUF_SIZE);
@@ -157,6 +217,7 @@ Buf init_buf(uint32_t size)
 	my_buf->size = size;
 	my_buf->processed = 0;
 	my_buf->head = xmalloc(sizeof(char)*size);
+	my_buf->mmaped = false;
 	return my_buf;
 }
 
@@ -167,6 +228,10 @@ void *xfer_buf_data(Buf my_buf)
 	void *data_ptr;
 
 	assert(my_buf->magic == BUF_MAGIC);
+
+	if (my_buf->mmaped)
+		fatal_abort("attempt to grow mmap()'d buffer not supported");
+
 	data_ptr = (void *) my_buf->head;
 	xfree(my_buf);
 	return data_ptr;
@@ -223,8 +288,10 @@ void 	packdouble(double val, Buf buffer)
 		uint64_t u;
 	} uval;
 
-	 /* The 0.5 is here to round off.  We have found on systems going out
-	  * more than 15 decimals will mess things up, but this corrects it. */
+	/*
+	 * The 0.5 is here to round off.  We have found on systems going out
+	 * more than 15 decimals will mess things up, but rounding corrects it.
+	 */
 	uval.d =  (val * FLOAT_MULT);
 	nl =  HTON_uint64(uval.u);
 	if (remaining_buf(buffer) < sizeof(nl)) {
@@ -378,7 +445,9 @@ int unpack32(uint32_t * valp, Buf buffer)
 	return SLURM_SUCCESS;
 }
 
-/* Given a *uint16_t, it will pack an array of size_val */
+/*
+ * Given a *uint16_t, it will pack an array of size_val
+ */
 void pack16_array(uint16_t * valp, uint32_t size_val, Buf buffer)
 {
 	uint32_t i = 0;
@@ -392,7 +461,8 @@ void pack16_array(uint16_t * valp, uint32_t size_val, Buf buffer)
 	}
 }
 
-/* Given a int ptr, it will unpack an array of size_val
+/*
+ * Given a int ptr, it will unpack an array of size_val
  */
 int unpack16_array(uint16_t ** valp, uint32_t * size_val, Buf buffer)
 {
@@ -400,7 +470,7 @@ int unpack16_array(uint16_t ** valp, uint32_t * size_val, Buf buffer)
 
 	if (unpack32(size_val, buffer))
 		return SLURM_ERROR;
-	if ((*size_val) > NO_VAL)
+	if ((*size_val) > MAX_ARRAY_LEN_MEDIUM)
 		return SLURM_ERROR;
 
 	*valp = xmalloc_nz((*size_val) * sizeof(uint16_t));
@@ -411,7 +481,9 @@ int unpack16_array(uint16_t ** valp, uint32_t * size_val, Buf buffer)
 	return SLURM_SUCCESS;
 }
 
-/* Given a *uint32_t, it will pack an array of size_val */
+/*
+ * Given a *uint32_t, it will pack an array of size_val
+ */
 void pack32_array(uint32_t * valp, uint32_t size_val, Buf buffer)
 {
 	uint32_t i = 0;
@@ -425,7 +497,8 @@ void pack32_array(uint32_t * valp, uint32_t size_val, Buf buffer)
 	}
 }
 
-/* Given a int ptr, it will unpack an array of size_val
+/*
+ * Given a int ptr, it will unpack an array of size_val
  */
 int unpack32_array(uint32_t ** valp, uint32_t * size_val, Buf buffer)
 {
@@ -433,7 +506,7 @@ int unpack32_array(uint32_t ** valp, uint32_t * size_val, Buf buffer)
 
 	if (unpack32(size_val, buffer))
 		return SLURM_ERROR;
-	if ((*size_val) > NO_VAL)
+	if ((*size_val) > MAX_ARRAY_LEN_LARGE)
 		return SLURM_ERROR;
 
 	*valp = xmalloc_nz((*size_val) * sizeof(uint32_t));
@@ -444,7 +517,9 @@ int unpack32_array(uint32_t ** valp, uint32_t * size_val, Buf buffer)
 	return SLURM_SUCCESS;
 }
 
-/* Given a *uint64_t, it will pack an array of size_val */
+/*
+ * Given a *uint64_t, it will pack an array of size_val
+ */
 void pack64_array(uint64_t * valp, uint32_t size_val, Buf buffer)
 {
 	uint32_t i = 0;
@@ -458,8 +533,10 @@ void pack64_array(uint64_t * valp, uint32_t size_val, Buf buffer)
 	}
 }
 
-/* Pack an array of 64bit values as if they were 32bit
- * Used for backwards compatibility */
+/*
+ * Pack an array of 64b-it values as if they were 32-bit
+ * Used for backwards compatibility
+ */
 void pack64_array_as_32(uint64_t * valp, uint32_t size_val, Buf buffer)
 {
 	uint32_t i = 0;
@@ -481,7 +558,7 @@ int unpack64_array(uint64_t ** valp, uint32_t * size_val, Buf buffer)
 
 	if (unpack32(size_val, buffer))
 		return SLURM_ERROR;
-	if ((*size_val) > NO_VAL)
+	if ((*size_val) > MAX_ARRAY_LEN_MEDIUM)
 		return SLURM_ERROR;
 
 	*valp = xmalloc_nz((*size_val) * sizeof(uint64_t));
@@ -492,15 +569,17 @@ int unpack64_array(uint64_t ** valp, uint32_t * size_val, Buf buffer)
 	return SLURM_SUCCESS;
 }
 
-/* Unpack an array of 64bit values as if they were 32bit
- * Used for backwards compatibility */
+/*
+ * Unpack an array of 64bit values as if they were 32bit
+ * Used for backwards compatibility
+ */
 int unpack64_array_from_32(uint64_t ** valp, uint32_t * size_val, Buf buffer)
 {
 	uint32_t i = 0, val32;
 
 	if (unpack32(size_val, buffer))
 		return SLURM_ERROR;
-	if ((*size_val) > NO_VAL)
+	if ((*size_val) > MAX_ARRAY_LEN_MEDIUM)
 		return SLURM_ERROR;
 
 	*valp = xmalloc_nz((*size_val) * sizeof(uint64_t));
@@ -531,7 +610,7 @@ int unpackdouble_array(double **valp, uint32_t* size_val, Buf buffer)
 
 	if (unpack32(size_val, buffer))
 		return SLURM_ERROR;
-	if ((*size_val) > NO_VAL)
+	if ((*size_val) > MAX_ARRAY_LEN_SMALL)
 		return SLURM_ERROR;
 
 	*valp = xmalloc_nz((*size_val) * sizeof(double));
@@ -561,7 +640,7 @@ int unpacklongdouble_array(long double **valp, uint32_t* size_val, Buf buffer)
 
 	if (unpack32(size_val, buffer))
 		return SLURM_ERROR;
-	if ((*size_val) > NO_VAL)
+	if ((*size_val) > MAX_ARRAY_LEN_SMALL)
 		return SLURM_ERROR;
 
 	*valp = xmalloc_nz((*size_val) * sizeof(long double));
@@ -703,9 +782,9 @@ int unpackmem_ptr(char **valp, uint32_t * size_valp, Buf buffer)
 	*size_valp = ntohl(ns);
 	buffer->processed += sizeof(ns);
 
-	if (*size_valp > MAX_PACK_MEM_LEN) {
+	if (*size_valp > MAX_ARRAY_LEN_LARGE) {
 		error("%s: Buffer to be unpacked is too large (%u > %u)",
-		      __func__, *size_valp, MAX_PACK_MEM_LEN);
+		      __func__, *size_valp, MAX_ARRAY_LEN_LARGE);
 		return SLURM_ERROR;
 	}
 	else if (*size_valp > 0) {
@@ -738,9 +817,9 @@ int unpackmem(char *valp, uint32_t * size_valp, Buf buffer)
 	*size_valp = ntohl(ns);
 	buffer->processed += sizeof(ns);
 
-	if (*size_valp > MAX_PACK_MEM_LEN) {
+	if (*size_valp > MAX_ARRAY_LEN_LARGE) {
 		error("%s: Buffer to be unpacked is too large (%u > %u)",
-		      __func__, *size_valp, MAX_PACK_MEM_LEN);
+		      __func__, *size_valp, MAX_ARRAY_LEN_LARGE);
 		return SLURM_ERROR;
 	}
 	else if (*size_valp > 0) {
@@ -773,9 +852,9 @@ int unpackmem_xmalloc(char **valp, uint32_t * size_valp, Buf buffer)
 	*size_valp = ntohl(ns);
 	buffer->processed += sizeof(ns);
 
-	if (*size_valp > MAX_PACK_MEM_LEN) {
+	if (*size_valp > MAX_ARRAY_LEN_LARGE) {
 		error("%s: Buffer to be unpacked is too large (%u > %u)",
-		      __func__, *size_valp, MAX_PACK_MEM_LEN);
+		      __func__, *size_valp, MAX_ARRAY_LEN_LARGE);
 		return SLURM_ERROR;
 	}
 	else if (*size_valp > 0) {
@@ -809,9 +888,9 @@ int unpackmem_malloc(char **valp, uint32_t * size_valp, Buf buffer)
 	memcpy(&ns, &buffer->head[buffer->processed], sizeof(ns));
 	*size_valp = ntohl(ns);
 	buffer->processed += sizeof(ns);
-	if (*size_valp > MAX_PACK_MEM_LEN) {
+	if (*size_valp > MAX_ARRAY_LEN_SMALL) {
 		error("%s: Buffer to be unpacked is too large (%u > %u)",
-		      __func__, *size_valp, MAX_PACK_MEM_LEN);
+		      __func__, *size_valp, MAX_ARRAY_LEN_SMALL);
 		return SLURM_ERROR;
 	}
 	else if (*size_valp > 0) {
@@ -954,9 +1033,9 @@ int unpackstr_array(char ***valp, uint32_t * size_valp, Buf buffer)
 	*size_valp = ntohl(ns);
 	buffer->processed += sizeof(ns);
 
-	if (*size_valp > MAX_PACK_ARRAY_LEN) {
+	if (*size_valp > MAX_ARRAY_LEN_MEDIUM) {
 		error("%s: Buffer to be unpacked is too large (%u > %u)",
-		      __func__, *size_valp, MAX_PACK_ARRAY_LEN);
+		      __func__, *size_valp, MAX_ARRAY_LEN_MEDIUM);
 		return SLURM_ERROR;
 	}
 	else if (*size_valp > 0) {
@@ -965,8 +1044,10 @@ int unpackstr_array(char ***valp, uint32_t * size_valp, Buf buffer)
 			if (unpackmem_xmalloc(&(*valp)[i], &uint32_tmp, buffer))
 				return SLURM_ERROR;
 		}
-		(*valp)[i] = NULL;	/* NULL terminated array so that execle */
-		/*    can detect end of array */
+		/*
+		 * NULL terminate array so execle() can detect end of array
+		 */
+		(*valp)[i] = NULL;
 	} else
 		*valp = NULL;
 	return SLURM_SUCCESS;
