@@ -7,11 +7,11 @@
  *  Written by Jay Windley <jwindley@lnxi.com>.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -472,16 +472,6 @@ _match_major ( const char *path_name, const char *major_type )
 	return true;
 }
 
-int
-plugrack_read_cache( plugrack_t rack,
-		     const char *cache_file )
-{
-	/* Don't care for now. */
-
-	return SLURM_ERROR;
-}
-
-
 int
 plugrack_purge_idle( plugrack_t rack )
 {
@@ -525,16 +515,6 @@ plugrack_load_all( plugrack_t rack )
 	return SLURM_SUCCESS;
 }
 
-
-int
-plugrack_write_cache( plugrack_t rack,
-		      const char *cache )
-{
-	/* Not implemented. */
-
-	return SLURM_SUCCESS;
-}
-
 plugin_handle_t
 plugrack_use_by_type( plugrack_t rack,
 		      const char *full_type )
