@@ -10,11 +10,11 @@
  *  Written by Morris Mette <jette1@llnl.gov>.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -30,13 +30,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -68,7 +68,7 @@ extern uint16_t drop_priv_flag;
 #define ACCOUNTING_ENFORCE_NO_STEPS 0x0040
 #define ACCOUNTING_ENFORCE_TRES   0x0080
 
-#define DEFAULT_ACCOUNTING_TRES  "cpu,mem,energy,node,billing"
+#define DEFAULT_ACCOUNTING_TRES  "cpu,mem,energy,node,billing,fs/disk,vmem,pages"
 #define DEFAULT_ACCOUNTING_DB      "slurm_acct_db"
 #define DEFAULT_ACCOUNTING_ENFORCE  0
 #define DEFAULT_ACCOUNTING_STORAGE_TYPE "accounting_storage/none"
@@ -114,9 +114,7 @@ extern uint16_t drop_priv_flag;
 #define DEFAULT_KILL_TREE           0
 #define DEFAULT_KILL_WAIT           30
 
-#if defined HAVE_BG_FILES
-#  define DEFAULT_LAUNCH_TYPE         "launch/runjob"
-#elif defined HAVE_LIBNRT
+#if defined HAVE_LIBNRT
 #  define DEFAULT_LAUNCH_TYPE         "launch/poe"
 #elif defined HAVE_ALPS_CRAY && defined HAVE_REAL_CRAY
 #  define DEFAULT_LAUNCH_TYPE         "launch/aprun"
@@ -125,6 +123,7 @@ extern uint16_t drop_priv_flag;
 #endif
 
 #define DEFAULT_MAIL_PROG           "/bin/mail"
+#define DEFAULT_MAIL_PROG_ALT       "/usr/bin/mail"
 #define DEFAULT_MAX_ARRAY_SIZE      1001
 #define DEFAULT_MAX_JOB_COUNT       10000
 #define DEFAULT_MAX_JOB_ID          0x03ff0000
@@ -157,9 +156,7 @@ extern uint16_t drop_priv_flag;
 #define DEFAULT_SCHED_LOG_LEVEL     0
 #define DEFAULT_SCHED_TIME_SLICE    30
 #define DEFAULT_SCHEDTYPE           "sched/backfill"
-#ifdef HAVE_BG	/* Blue Gene specific default configuration parameters */
-#  define DEFAULT_SELECT_TYPE       "select/bluegene"
-#elif defined HAVE_ALPS_CRAY
+#if defined HAVE_ALPS_CRAY
 #  define DEFAULT_SELECT_TYPE       "select/alps"
 #elif defined HAVE_NATIVE_CRAY
 #  define DEFAULT_SELECT_TYPE       "select/cray"
@@ -221,6 +218,7 @@ typedef struct slurm_conf_node {
 	char *gres;		/* arbitrary list of node's generic resources */
 	char *feature;		/* arbitrary list of node's features */
 	char *port_str;
+	uint32_t cpu_bind;	/* default CPU bind type */
 	uint16_t cpus;		/* count of cpus running on the node */
 	char *cpu_spec_list;	/* arbitrary list of specialized cpus */
 	uint16_t boards; 	/* number of boards per node */
@@ -248,23 +246,25 @@ typedef struct slurm_conf_partition {
 				 * NULL indicates all */
 	char *allow_qos;        /* comma delimited list of qos,
 			         * NULL indicates all */
+	char *alternate;	/* name of alternate partition */
+	char *billing_weights_str;/* per TRES billing weights */
+	uint32_t cpu_bind;	/* default CPU binding type */
+	uint16_t cr_type;	/* Custom CR values for partition (supported
+				 * by select/cons_res plugin only) */
+	uint64_t def_mem_per_cpu; /* default MB memory per allocated CPU */
+	bool default_flag;	/* Set if default partition */
+	uint32_t default_time;	/* minutes or INFINITE */
 	char *deny_accounts;    /* comma delimited list of denied accounts,
 				 * NULL indicates all */
 	char *deny_qos;		/* comma delimited list of denied qos,
 				 * NULL indicates all */
-	char *alternate;	/* name of alternate partition */
-	uint16_t cr_type;	/* Custom CR values for partition (supported
-				 * by select/cons_res plugin only) */
-	char *billing_weights_str;/* per TRES billing weights */
-	uint64_t def_mem_per_cpu; /* default MB memory per allocated CPU */
-	bool default_flag;	/* Set if default partition */
-	uint32_t default_time;	/* minutes or INFINITE */
 	uint16_t disable_root_jobs; /* if set then user root can't run
 				     * jobs if NO_VAL use global
 				     * default */
 	uint16_t exclusive_user; /* 1 if node allocations by user */
 	uint32_t grace_time;	/* default grace time for partition */
 	bool     hidden_flag;	/* 1 if hidden by default */
+	List job_defaults_list;	/* List of job_defaults_t elements */
 	bool     lln_flag;	/* 1 if nodes are selected in LLN order */
 	uint32_t max_cpus_per_node; /* maximum allocated CPUs per node */
 	uint16_t max_share;	/* number of jobs to gang schedule */
@@ -300,9 +300,52 @@ typedef struct {
 	char *value;
 } config_key_pair_t;
 
+typedef struct {
+	char *name;
+	List key_pairs;
+} config_plugin_params_t;
+
+/*
+ * Get result of configuration file test.
+ * RET SLURM_SUCCESS or error code
+ */
+extern int config_test_result(void);
+
+/*
+ * Start configuration file test mode. Disables fatal errors.
+ */
+extern void config_test_start(void);
+
 /* Destroy a front_end record built by slurm_conf_frontend_array() */
 extern void destroy_frontend(void *ptr);
 
+/* Copy list of job_defaults_t elements */
+extern List job_defaults_copy(List in_list);
+
+/* Destroy list of job_defaults_t elements */
+extern void job_defaults_free(void *x);
+
+/*
+ * Translate string of job_defaults_t elements into a List.
+ * in_str IN - comma separated key=value pairs
+ * out_list OUT - equivalent list of key=value pairs
+ * Returns SLURM_SUCCESS or an error code
+ */
+extern int job_defaults_list(char *in_str, List *out_list);
+
+/*
+ * Translate list of job_defaults_t elements into a string.
+ * Return value must be released using xfree()
+ */
+extern char *job_defaults_str(List in_list);
+
+/* Pack a job_defaults_t element. Used by slurm_pack_list() */
+extern void job_defaults_pack(void *in, uint16_t protocol_version, Buf buffer);
+
+/* Unpack a job_defaults_t element. Used by slurm_pack_list() */
+extern int job_defaults_unpack(void **out, uint16_t protocol_version,
+			       Buf buffer);
+
 /*
  * list_find_frontend - find an entry in the front_end list, see list.h for
  *	documentation
@@ -566,10 +609,27 @@ extern char *reconfig_flags2str(uint16_t reconfig_flags);
  */
 extern uint16_t reconfig_str2flags(char *reconfig_flags);
 
+extern void destroy_config_plugin_params(void *object);
+extern void pack_config_plugin_params(void *in, uint16_t protocol_version,
+				      Buf buff);
+extern int unpack_config_plugin_params(void **object, uint16_t protocol_version,
+				       Buf buff);
+extern void pack_config_plugin_params_list(void *in, uint16_t protocol_version,
+					   Buf buff);
+extern int unpack_config_plugin_params_list(void **object,
+					    uint16_t protocol_version,
+					    Buf buff);
+
 extern void destroy_config_key_pair(void *object);
-extern void pack_config_key_pair(void *in, uint16_t rpc_version, Buf buffer);
-extern int unpack_config_key_pair(void **object, uint16_t rpc_version,
+extern void pack_key_pair_list(void *key_pairs, uint16_t protocol_version,
+			       Buf buffer);
+extern int unpack_key_pair_list(void **key_pairs, uint16_t protocol_version,
+				Buf buffer);
+extern void pack_config_key_pair(void *in, uint16_t protocol_version,
+				 Buf buffer);
+extern int unpack_config_key_pair(void **object, uint16_t protocol_version,
 				  Buf buffer);
+
 extern int sort_key_pairs(void *v1, void *v2);
 /*
  * Return the pathname of the extra .conf file
