@@ -7,11 +7,11 @@
  *
  *  Written by Rod Schultz <rod.schultz@bull.com>
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -53,6 +53,7 @@
 #include "src/common/plugin.h"
 #include "src/common/plugrack.h"
 #include "src/common/read_config.h"
+#include "src/common/slurm_acct_gather_filesystem.h"
 #include "src/common/slurm_acct_gather_interconnect.h"
 #include "src/common/slurm_acct_gather_profile.h"
 #include "src/common/slurm_acct_gather_energy.h"
@@ -282,7 +283,9 @@ extern int acct_gather_profile_fini(void)
 	}
 
 	if (timer_thread_id) {
+		slurm_mutex_lock(&timer_thread_mutex);
 		slurm_cond_signal(&timer_thread_cond);
+		slurm_mutex_unlock(&timer_thread_mutex);
 		pthread_join(timer_thread_id, NULL);
 	}
 
@@ -554,40 +557,42 @@ extern void acct_gather_profile_endpoll(void)
 	}
 }
 
-extern void acct_gather_profile_g_child_forked(void)
+extern int acct_gather_profile_g_child_forked(void)
 {
 	if (acct_gather_profile_init() < 0)
-		return;
+		return SLURM_ERROR;
+
 	(*(ops.child_forked))();
-	return;
+	return SLURM_SUCCESS;
 }
 
-extern void acct_gather_profile_g_conf_options(s_p_options_t **full_options,
+extern int acct_gather_profile_g_conf_options(s_p_options_t **full_options,
 					       int *full_options_cnt)
 {
 	if (acct_gather_profile_init() < 0)
-		return;
+		return SLURM_ERROR;
+
 	(*(ops.conf_options))(full_options, full_options_cnt);
-	return;
+	return SLURM_SUCCESS;
 }
 
-extern void acct_gather_profile_g_conf_set(s_p_hashtbl_t *tbl)
+extern int acct_gather_profile_g_conf_set(s_p_hashtbl_t *tbl)
 {
 	if (acct_gather_profile_init() < 0)
-		return;
+		return SLURM_ERROR;
 
 	(*(ops.conf_set))(tbl);
-	return;
+	return SLURM_SUCCESS;
 }
 
-extern void acct_gather_profile_g_get(enum acct_gather_profile_info info_type,
+extern int acct_gather_profile_g_get(enum acct_gather_profile_info info_type,
 				      void *data)
 {
 	if (acct_gather_profile_init() < 0)
-		return;
+		return SLURM_ERROR;
 
 	(*(ops.get))(info_type, data);
-	return;
+	return SLURM_SUCCESS;
 }
 
 extern int acct_gather_profile_g_node_step_start(stepd_step_rec_t* job)
@@ -699,4 +704,3 @@ extern bool acct_gather_profile_test(void)
 	slurm_mutex_unlock(&profile_running_mutex);
 	return rc;
 }
-
