@@ -6,11 +6,11 @@
  *  Written by Mark Grondona <mgrondona@llnl.gov>.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -26,13 +26,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -115,21 +115,4 @@ char *gid_to_string (gid_t gid);
 int
 slurm_find_group_user(struct passwd *pwd, gid_t gid);
 
-/* slurm_valid_uid_gid()
- *
- * IN - uid - User id to verify
- * IN/OUT - gid - Group id to verify or set
- * IN/OUT - user_name - User name for the uid, this will be set if not
- *                      already set.
- * IN - name_already_verfied - If set we will only validate the
- *                             *user_name exists and return 1, else we
- *                             will validate uid and fill in *user_name.
- * IN - validate_gid - If set we will validate the gid as well as the
- *                     uid.  Set gid with correct gid if root launched job.
- * RET - returns 0 if invalid uid/gid, otherwise returns 1
- */
-extern int slurm_valid_uid_gid(uid_t uid, gid_t *gid, char **user_name,
-			       bool name_already_verified,
-			       bool validate_gid);
-
 #endif /*__SLURM_UID_UTILITY_H__*/
