@@ -3,11 +3,11 @@
  *****************************************************************************
  *  Copyright (C) 2012 CEA/DAM/DIF
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -23,13 +23,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -80,10 +80,7 @@ typedef void (*xhash_freefunc_t)(void* item);
  *
  * @returns the newly allocated hash table. Must be freed with xhash_free.
  */
-xhash_t* xhash_init(xhash_idfunc_t idfunc,
-		    xhash_freefunc_t freefunc,
-		    xhash_hashfunc_t hashfunc, /* Currently: should be NULL */
-		    uint32_t table_size);      /* Currently: unused         */
+xhash_t *xhash_init(xhash_idfunc_t idfunc, xhash_freefunc_t freefunc);
 
 /** @returns an item from a key searching through the hash table. NULL if not
  * found.
@@ -130,4 +127,3 @@ void xhash_clear(xhash_t* table);
 void xhash_free_ptr(xhash_t** table);
 
 #endif
-
