@@ -143,6 +143,7 @@ static void _get_joules_task(acct_gather_energy_t *energy)
 	uint64_t curr_energy, diff_energy = 0;
 	uint32_t curr_power;
 	time_t now;
+	static uint32_t readings = 0;
 
 	if (energy->current_watts == NO_VAL)
 		return;
@@ -155,17 +156,18 @@ static void _get_joules_task(acct_gather_energy_t *energy)
 		diff_energy = curr_energy - energy->previous_consumed_energy;
 
 		energy->consumed_energy += diff_energy;
-	} else
+		energy->base_watts =  ((energy->base_watts * readings) +
+				       energy->current_watts) / (readings + 1);
+	} else {
 		energy->base_consumed_energy = curr_energy;
-
+		energy->base_watts = 0;
+	}
+	readings++;
 	energy->current_watts = curr_power;
 
-	if (!energy->base_watts || (energy->base_watts > curr_power))
-		energy->base_watts = curr_power;
-
 	if (debug_flags & DEBUG_FLAG_ENERGY)
 		info("_get_joules_task: %"PRIu64" Joules consumed over last"
-		     " %ld secs. Currently at %u watts, lowest watts %u",
+		     " %ld secs. Currently at %u watts, ave watts %u",
 		     diff_energy,
 		     energy->poll_time ? now - energy->poll_time : 0,
 		     curr_power, energy->base_watts);
