@@ -5,11 +5,11 @@
  *  Copyright (C) 2015-2017 Mellanox Technologies. All rights reserved.
  *  Written by Artem Polyakov <artpol84@gmail.com, artemp@mellanox.com>.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -25,13 +25,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  \*****************************************************************************/
 
@@ -94,7 +94,7 @@
 	PMIX_VAL_SET(value, int, rank);				\
 }
 
-#elif (HAVE_PMIX_VER == 2)
+#else
 #define PMIXP_INFO_ARRAY_CREATE(kvp, _array, _count)			\
 {									\
 	(kvp)->value.type = PMIX_DATA_ARRAY;				\
@@ -163,7 +163,7 @@ static void _set_tmpdirs(List lresp)
 	bool rmclean = true;
 
 	/* We consider two sources of the tempdir:
-	 * - SLURM's slurm.conf TmpFS option;
+	 * - Slurm's slurm.conf TmpFS option;
 	 * - env var SLURM_PMIX_TMPDIR;
 	 * do we need to do anything else?
 	 */
@@ -218,7 +218,7 @@ static void _set_procdatas(List lresp)
 		list_append(rankinfo, kvp);
 
 		/* TODO: always use 0 for now. This is not the general case
-		 * though (see SLURM MIMD: man srun, section MULTIPLE PROGRAM
+		 * though (see Slurm MIMD: man srun, section MULTIPLE PROGRAM
 		 * CONFIGURATION)
 		 */
 		PMIXP_ALLOC_KEY(kvp, PMIX_APPNUM);
@@ -708,3 +708,42 @@ extern int pmixp_libpmix_job_set(void)
 
 	return ret;
 }
+
+extern int pmixp_lib_fence(const pmixp_proc_t procs[], size_t nprocs,
+			   bool collect, char *data, size_t ndata,
+			   void *cbfunc, void *cbdata)
+{
+	pmixp_coll_t *coll;
+	pmix_status_t status;
+	pmix_modex_cbfunc_t modex_cbfunc = (pmix_modex_cbfunc_t)cbfunc;
+	int ret;
+
+	/* Chooses the coll algorithm defined by user
+	 * thru the env variable: SLURM_PMIXP_FENCE.
+	 * By default: PMIXP_COLL_TYPE_FENCE_AUTO
+	 * is used the both fence algorithms */
+	pmixp_coll_type_t type = pmixp_info_srv_fence_coll_type();
+
+	if (PMIXP_COLL_TYPE_FENCE_MAX == type) {
+		type = PMIXP_COLL_TYPE_FENCE_TREE;
+		if (collect) {
+			type = PMIXP_COLL_TYPE_FENCE_RING;
+		}
+	}
+
+	coll = pmixp_state_coll_get(type, procs, nprocs);
+	if (!coll) {
+		status = PMIX_ERROR;
+		goto error;
+	}
+	ret = pmixp_coll_contrib_local(coll, type, data, ndata, cbfunc, cbdata);
+	if (SLURM_SUCCESS != ret) {
+		status = PMIX_ERROR;
+		goto error;
+	}
+	return SLURM_SUCCESS;
+
+error:
+	modex_cbfunc(status, NULL, 0, cbdata, NULL, NULL);
+	return SLURM_ERROR;
+}
