@@ -4,11 +4,11 @@
  *  Copyright (C) 2013 SchedMD LLC
  *  Written by Morris Jette <jette@schedmd.com>
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -24,13 +24,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -108,8 +108,7 @@ static void _job_fail_del(void *x)
 	if (job_fail_ptr->pending_job_id) {
 		job_ptr = find_job_record(job_fail_ptr->pending_job_id);
 		if (job_ptr && (job_ptr->user_id == job_fail_ptr->user_id)) {
-			(void) job_signal(job_fail_ptr->pending_job_id,
-					  SIGKILL, 0, 0, false);
+			(void) job_signal(job_ptr, SIGKILL, 0, 0, false);
 		}
 	}
 	xfree(job_fail_ptr->fail_node_cpus);
@@ -507,7 +506,7 @@ static void _failing_node(struct node_record *node_ptr)
 	info("node_fail_callback for node:%s", node_ptr->name);
 	if (!job_fail_list)
 		return;
-	if (IS_NODE_DOWN(node_ptr) || IS_NODE_ERROR(node_ptr))
+	if (IS_NODE_DOWN(node_ptr))
 		event_flag |= SMD_EVENT_NODE_FAILED;
 	if (IS_NODE_FAIL(node_ptr))
 		event_flag |= SMD_EVENT_NODE_FAILING;
@@ -542,7 +541,7 @@ extern void node_fail_callback(struct job_record *job_ptr,
 
 	info("node_fail_callback for job:%u node:%s",
 	     job_ptr->job_id, node_ptr->name);
-	if (IS_NODE_DOWN(node_ptr) || IS_NODE_ERROR(node_ptr))
+	if (IS_NODE_DOWN(node_ptr))
 		event_flag |= SMD_EVENT_NODE_FAILED;
 	if (IS_NODE_FAIL(node_ptr))
 		event_flag |= SMD_EVENT_NODE_FAILING;
@@ -789,7 +788,7 @@ static void _kill_job(uint32_t job_id, uid_t cmd_uid)
 {
 	int rc;
 
-	rc = job_signal(job_id, SIGKILL, 0, cmd_uid, false);
+	rc = job_signal_id(job_id, SIGKILL, 0, cmd_uid, false);
 	if (rc) {
 		info("slurmctld/nonstop: can not kill job %u: %s",
 		     job_id, slurm_strerror(rc));
@@ -1235,14 +1234,15 @@ extern char *replace_node(char *cmd_ptr, uid_t cmd_uid,
 		goto fini;
 	}
 
-	/* Create a job with replacement resources,
-	 * which will later be merged into the original job */
+	/*
+	 * Create a job with replacement resources,
+	 * which will later be merged into the original job
+	 */
 	slurm_init_job_desc_msg(&job_alloc_req);
 	job_alloc_req.account = xstrdup(job_ptr->account);
 	xstrfmtcat(job_alloc_req.dependency, "expand:%u", job_ptr->job_id);
 	job_alloc_req.exc_nodes = xstrdup(job_ptr->nodes);
 	job_alloc_req.features  = _job_node_features(job_ptr, node_ptr);
-	job_alloc_req.gres	= xstrdup(job_ptr->gres);
 	job_alloc_req.group_id	= job_ptr->group_id;
 	job_alloc_req.immediate	= 1;
 	job_alloc_req.max_cpus	= cpu_cnt;
@@ -1255,9 +1255,15 @@ extern char *replace_node(char *cmd_ptr, uid_t cmd_uid,
 	job_alloc_req.priority	= NO_VAL - 1;
 	if (job_ptr->qos_ptr)
 		job_alloc_req.qos = xstrdup(job_ptr->qos_ptr->name);
+	job_alloc_req.tres_per_job    = xstrdup(job_ptr->tres_per_job);
+	job_alloc_req.tres_per_node   = xstrdup(job_ptr->tres_per_node);
+	job_alloc_req.tres_per_socket = xstrdup(job_ptr->tres_per_socket);
+	job_alloc_req.tres_per_task   = xstrdup(job_ptr->tres_per_task);
 
-	/* Without unlock, the job_begin_callback() function will deadlock.
-	 * Not a great solution, but perhaps the least bad solution. */
+	/*
+	 * Without unlock, the job_begin_callback() function will deadlock.
+	 * Not a great solution, but perhaps the least bad solution.
+	 */
 	slurm_mutex_unlock(&job_fail_mutex);
 
 	job_alloc_req.user_id	= job_ptr->user_id;
@@ -1341,11 +1347,13 @@ extern char *replace_node(char *cmd_ptr, uid_t cmd_uid,
 	xfree(job_alloc_req.dependency);
 	xfree(job_alloc_req.exc_nodes);
 	xfree(job_alloc_req.features);
-	xfree(job_alloc_req.gres);
 	xfree(job_alloc_req.name);
 	xfree(job_alloc_req.network);
 	xfree(job_alloc_req.partition);
 	xfree(job_alloc_req.qos);
+	xfree(job_alloc_req.tres_per_node);
+	xfree(job_alloc_req.tres_per_socket);
+	xfree(job_alloc_req.tres_per_task);
 	xfree(job_alloc_req.wckey);
 
 	slurm_mutex_lock(&job_fail_mutex);	/* Resume lock */
@@ -1706,7 +1714,7 @@ static void _send_event_callbacks(void)
 	ListIterator job_iterator;
 	slurm_addr_t callback_addr;
 	uint32_t callback_flags, callback_jobid;
-	int fd, retry = 0;
+	int fd;
 	ssize_t sent;
 
 	if (!job_fail_list)
@@ -1743,14 +1751,8 @@ static void _send_event_callbacks(void)
 			}
 			sent = slurm_msg_sendto_timeout(fd,
 					(char *) &callback_flags,
-					sizeof(uint32_t), 0, 100000);
-			while ((slurm_shutdown_msg_conn(fd) < 0) &&
-			       (errno == EINTR)) {
-				if (retry++ > 10) {
-					error("nonstop: socket close fail: %m");
-					break;
-				}
-			}
+					sizeof(uint32_t), 100000);
+			(void) close(fd);
 			/* Reset locks and clean-up as needed */
 io_fini:		slurm_mutex_lock(&job_fail_mutex);
 			if ((sent != sizeof(uint32_t)) &&
