@@ -7,11 +7,11 @@
  *  Written by Morris Jette <jette1@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -65,14 +65,14 @@
  * plugin_type - a string suggesting the type of the plugin or its
  * applicability to a particular form of data or method of data handling.
  * If the low-level plugin API is used, the contents of this string are
- * unimportant and may be anything.  SLURM uses the higher-level plugin
+ * unimportant and may be anything.  Slurm uses the higher-level plugin
  * interface which requires this string to be of the form
  *
  *      <application>/<method>
  *
  * where <application> is a description of the intended application of
  * the plugin (e.g., "task" for task control) and <method> is a description
- * of how this plugin satisfies that application.  SLURM will only load
+ * of how this plugin satisfies that application.  Slurm will only load
  * a task plugin if the plugin_type string has a prefix of "task/".
  *
  * plugin_version - an unsigned 32-bit integer containing the Slurm version
@@ -268,7 +268,7 @@ extern bool topo_generate_node_ranking(void)
 	// Free the old switch data table since it is no longer needed
 	_free_switch_data_table();
 
-	// Return false to prevent SLURM from doing additional node ordering 
+	// Return false to prevent Slurm from doing additional node ordering 
 	return false;
 }
 
@@ -467,7 +467,7 @@ static int _node_name2bitmap(char *node_names, bitstr_t **bitmap,
 				(bitoff_t) (node_ptr - node_record_table_ptr));
 		} else {
 			fatal("Node \"%s\" specified in topology.conf but "
-			      "SLURM has no record of node. Verify that node "
+			      "Slurm has no record of node. Verify that node "
 			      "\"%s\" is specified in slurm.conf",
 			      this_node_name, this_node_name);
 		}
@@ -507,7 +507,7 @@ static int _parse_connected_nodes(switch_data *sw_record)
 			conn_count++;
 		} else {
 			fatal("Node \"%s\" connected to switch %s specified in "
-			      "topology.conf but SLURM has no record of node. "
+			      "topology.conf but Slurm has no record of node. "
 			      "Verify that node \"%s\" is specified in "
 			      "slurm.conf",
 			      node_name, sw_record->name,node_name);
@@ -1267,27 +1267,28 @@ static void _print_switch_data_table(void)
 /* prints name and coordinates of all switches in hypercube switch table*/
 static void _print_hypercube_switch_table( int num_curves )
 {
-	char distances[512], nodes[512];
 	int i, j;
 
 	debug("Hypercube table has %d switch records in it",
 	      hypercube_switch_cnt);
 	for (i = 0; i < hypercube_switch_cnt; i++ ) {
-		strcpy(distances, "Distances: ");
+		char *distances = xstrdup("Distances: ");
+		char *nodes = xstrdup("Node Index: ");
 		for ( j = 0; j < num_curves; j++ ){
 			if (hypercube_switch_table[i].distance[j]) {
-				sprintf(distances, "%s%d, ", distances, 
-					hypercube_switch_table[i].distance[j]);
+				xstrfmtcat(distances, "%d, ",
+					   hypercube_switch_table[i].distance[j]);
 			} else
 				break;
 		}
-		strcpy(nodes, "Node Index: ");
 		for ( j = 0; j < hypercube_switch_table[i].node_cnt; j++ ) {
-			sprintf(nodes, "%s%d, ", nodes,
-				hypercube_switch_table[i].node_index[j]);
+			xstrfmtcat(nodes, "%d, ",
+				   hypercube_switch_table[i].node_index[j]);
 		}
-		debug("    %s: %d - %s %s", switch_data_table[i].name,
-		      i, distances,nodes);
+		debug("    %s: %d - %s %s",
+		      switch_data_table[i].name, i, distances,nodes);
+		xfree(distances);
+		xfree(nodes);
 	}
 }
 
@@ -1296,18 +1297,18 @@ static void _print_hypercube_switch_table( int num_curves )
 static void _print_sorted_hilbert_curves( int num_curves )
 {
 	int i, j;
-	char s[256];
 
 	debug("Hilbert Curves Ranking Created for %d Hilbert Curves",
 	      num_curves);
 	for ( i = 0 ; i < hypercube_switch_cnt ; i++ ) {
-		strcpy(s, "-- ");
+		char *s = xstrdup("-- ");
 		for ( j = 0 ; j < num_curves ; j++ ) {
-			sprintf(s,"%s%7s -%4d,  ", s,
-				hypercube_switches[j][i]->switch_name,
-				hypercube_switches[j][i]->switch_index);
+			xstrfmtcat(s, "%7s -%4d,  ",
+				   hypercube_switches[j][i]->switch_name,
+				   hypercube_switches[j][i]->switch_index);
 		}
 		debug("%s", s);
+		xfree(s);
 	}
 }
 
