@@ -8,11 +8,11 @@
  *  Written by Danny Auble <da@llnl.gov>.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -28,13 +28,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -54,6 +54,7 @@
 #define OPT_LONG_NOCONVERT 0x103
 #define OPT_LONG_UNITS     0x104
 #define OPT_LONG_FEDR      0x105
+#define OPT_LONG_WHETJOB   0x106
 
 #define JOB_HASH_SIZE 1000
 
@@ -96,7 +97,7 @@ static void _help_fields_msg(void)
 			printf(" ");
 		else if (i)
 			printf("\n");
-		printf("%-17s", fields[i].name);
+		printf("%-19s", fields[i].name);
 	}
 	printf("\n");
 	return;
@@ -316,7 +317,7 @@ sacct [<OPTION>]                                                            \n \
 	           is a '|'. This options is ignored if -p or -P options    \n\
 	           are not specified.                                       \n\
      -D, --duplicates:                                                      \n\
-	           If SLURM job ids are reset, some job numbers may         \n\
+	           If Slurm job ids are reset, some job numbers may         \n\
 	           appear more than once referring to different jobs.       \n\
 	           Without this option only the most recent jobs will be    \n\
                    displayed.                                               \n\
@@ -329,7 +330,7 @@ sacct [<OPTION>]                                                            \n \
                    this period.                                             \n\
          --federation: Report jobs from federation if a member of a one.    \n\
      -f, --file=file:                                                       \n\
-	           Read data from the specified file, rather than SLURM's   \n\
+	           Read data from the specified file, rather than Slurm's   \n\
                    current accounting log file. (Only appliciable when      \n\
                    running the filetxt plugin.)                             \n\
      -g, --gid, --group:                                                    \n\
@@ -424,6 +425,11 @@ sacct [<OPTION>]                                                            \n \
      -V, --version: Print version.                                          \n\
      -W, --wckeys:                                                          \n\
                    Only send data about these wckeys.  Default is all.      \n\
+     --whole-hetjob=[yes|no]:                                               \n\
+		   If set to 'yes' (or not set), then information about all \n\
+		   the heterogeneous components will be retrieved. If set   \n\
+		   to 'no' only the specific filtered components will be    \n\
+		   retrieved.                                               \n\
      -x, --associations:                                                    \n\
                    Only send data about these association id.  Default is all.\n\
      -X, --allocations:                                                     \n\
@@ -449,7 +455,7 @@ static void _init_params(void)
 {
 	memset(&params, 0, sizeof(sacct_parameters_t));
 	params.job_cond = xmalloc(sizeof(slurmdb_job_cond_t));
-	params.job_cond->without_usage_truncation = 1;
+	params.job_cond->flags |= JOBCOND_FLAG_NO_TRUNC;
 	params.convert_flags = CONVERT_NUM_UNIT_EXACT;
 	params.units = NO_VAL;
 }
@@ -554,6 +560,8 @@ extern int get_data(void)
 	ListIterator itr = NULL;
 	ListIterator itr_step = NULL;
 	slurmdb_job_cond_t *job_cond = params.job_cond;
+	int cnt;
+	char *tmp_usage;
 
 	if (params.opt_completion) {
 		jobs = slurmdb_jobcomp_jobs_get(job_cond);
@@ -565,23 +573,25 @@ extern int get_data(void)
 	if (!jobs)
 		return SLURM_ERROR;
 
-	/* Remove duplicate federated jobs. The db will remove duplicates for
+	/*
+	 * Remove duplicate federated jobs. The db will remove duplicates for
 	 * one cluster but not when jobs for multiple clusters are requested.
 	 * Remove the current job if there were jobs with the same id submitted
-	 * in the future. */
-	if (params.cluster_name && !params.opt_dup)
-	    _remove_duplicate_fed_jobs(jobs);
+	 * in the future.
+	 */
+	if (params.cluster_name && !(job_cond->flags & JOBCOND_FLAG_DUP))
+		_remove_duplicate_fed_jobs(jobs);
 
 	itr = list_iterator_create(jobs);
 	while ((job = list_next(itr))) {
 
 		if (job->user) {
-			struct	passwd *pw = NULL;
+			struct passwd *pw = NULL;
 			if ((pw=getpwnam(job->user)))
 				job->uid = pw->pw_uid;
 		}
 
-		if (!job->steps || !list_count(job->steps))
+		if (!job->steps || !(cnt = list_count(job->steps)))
 			continue;
 
 		itr_step = list_iterator_create(job->steps);
@@ -604,6 +614,17 @@ extern int get_data(void)
 			/* get the max for all the sacct_t struct */
 			aggregate_stats(&job->stats, &step->stats);
 		}
+
+		/* Now figure out the average of the total of averages */
+		tmp_usage = job->stats.tres_usage_in_ave;
+		job->stats.tres_usage_in_ave =
+			slurmdb_ave_tres_usage(tmp_usage, cnt);
+		xfree(tmp_usage);
+		tmp_usage = job->stats.tres_usage_out_ave;
+		job->stats.tres_usage_out_ave =
+			slurmdb_ave_tres_usage(tmp_usage, cnt);
+		xfree(tmp_usage);
+
 		list_iterator_destroy(itr_step);
 	}
 	list_iterator_destroy(itr);
@@ -675,6 +696,7 @@ extern void parse_command_line(int argc, char **argv)
                 {"verbose",        no_argument,       0,    'v'},
                 {"version",        no_argument,       0,    'V'},
                 {"wckeys",         required_argument, 0,    'W'},
+                {"whole-hetjob",   optional_argument, 0,    OPT_LONG_WHETJOB},
                 {"associations",   required_argument, 0,    'x'},
                 {0,                0,		      0,    0}};
 
@@ -737,7 +759,7 @@ extern void parse_command_line(int argc, char **argv)
 			slurm_addto_char_list(job_cond->cluster_list, optarg);
 			break;
 		case 'D':
-			params.opt_dup = 1;
+			job_cond->flags |= JOBCOND_FLAG_DUP;
 			break;
 		case 'e':
 			params.opt_help = 2;
@@ -900,7 +922,7 @@ extern void parse_command_line(int argc, char **argv)
 				exit(1);
 			break;
 		case 'T':
-			job_cond->without_usage_truncation = 0;
+			job_cond->flags &= ~JOBCOND_FLAG_NO_TRUNC;
 			break;
 		case 'U':
 			params.opt_help = 3;
@@ -927,6 +949,19 @@ extern void parse_command_line(int argc, char **argv)
 					list_create(slurm_destroy_char);
 			slurm_addto_char_list(job_cond->wckey_list, optarg);
 			break;
+		case OPT_LONG_WHETJOB:
+			if (!optarg || !xstrcasecmp(optarg, "yes") ||
+			    !xstrcasecmp(optarg, "y"))
+				job_cond->flags |= JOBCOND_FLAG_WHOLE_HETJOB;
+			else if (!xstrcasecmp(optarg, "no") ||
+				 !xstrcasecmp(optarg, "n"))
+				job_cond->flags |= JOBCOND_FLAG_NO_WHOLE_HETJOB;
+			else if (optarg) {
+				error("Invalid --whole-hetjob value \"%s\"."
+				      " Valid values: [yes|no].", optarg);
+				exit(1);
+			}
+			break;
 		case 'V':
 			print_slurm_version();
 			exit(0);
@@ -939,7 +974,7 @@ extern void parse_command_line(int argc, char **argv)
 		case 't':
 			/* 't' is deprecated and was replaced with 'X'.	*/
 		case 'X':
-			params.opt_allocs = 1;
+			job_cond->flags |= JOBCOND_FLAG_NO_STEP;
 			break;
 		case ':':
 		case '?':	/* getopt() has explained it */
@@ -953,14 +988,6 @@ extern void parse_command_line(int argc, char **argv)
 		log_alter(opts, 0, NULL);
 	}
 
-
-	/* Now set params.opt_dup, unless they've already done so */
-	if (params.opt_dup < 0)	/* not already set explicitly */
-		params.opt_dup = 0;
-
-	job_cond->duplicates = params.opt_dup;
-	job_cond->without_steps = params.opt_allocs;
-
 	if (!job_cond->usage_start && !job_cond->step_list) {
 		struct tm start_tm;
 		job_cond->usage_start = time(NULL);
@@ -978,7 +1005,6 @@ extern void parse_command_line(int argc, char **argv)
 			start_tm.tm_sec = 0;
 			start_tm.tm_min = 0;
 			start_tm.tm_hour = 0;
-			start_tm.tm_isdst = -1;
 			job_cond->usage_start = slurm_mktime(&start_tm);
 		}
 	}
@@ -999,12 +1025,15 @@ extern void parse_command_line(int argc, char **argv)
 	      "\topt_dup=%d\n"
 	      "\topt_field_list=%s\n"
 	      "\topt_help=%d\n"
-	      "\topt_allocs=%d",
+	      "\topt_no_steps=%d\n"
+	      "\topt_whole_hetjob=%s",
 	      params.opt_completion,
-	      params.opt_dup,
+	      job_cond->flags & JOBCOND_FLAG_DUP,
 	      params.opt_field_list,
 	      params.opt_help,
-	      params.opt_allocs);
+	      job_cond->flags & JOBCOND_FLAG_NO_STEP,
+	      job_cond->flags & JOBCOND_FLAG_WHOLE_HETJOB ? "yes" :
+	      (job_cond->flags & JOBCOND_FLAG_NO_WHOLE_HETJOB ? "no" : 0));
 
 	if (params.opt_completion) {
 		slurmdb_jobcomp_init(params.opt_filein);
@@ -1012,21 +1041,21 @@ extern void parse_command_line(int argc, char **argv)
 		acct_type = slurm_get_jobcomp_type();
 		if ((xstrcmp(acct_type, "jobcomp/none") == 0)
 		    &&  (stat(params.opt_filein, &stat_buf) != 0)) {
-			fprintf(stderr, "SLURM job completion is disabled\n");
+			fprintf(stderr, "Slurm job completion is disabled\n");
 			exit(1);
 		}
 		xfree(acct_type);
 	} else {
 		if (slurm_acct_storage_init(params.opt_filein) !=
 		    SLURM_SUCCESS) {
-			fprintf(stderr, "SLURM unable to initialize storage plugin\n");
+			fprintf(stderr, "Slurm unable to initialize storage plugin\n");
 			exit(1);
 		}
 		acct_type = slurm_get_accounting_storage_type();
 		if ((xstrcmp(acct_type, "accounting_storage/none") == 0)
 		    &&  (stat(params.opt_filein, &stat_buf) != 0)) {
 			fprintf(stderr,
-				"SLURM accounting storage is disabled\n");
+				"Slurm accounting storage is disabled\n");
 			exit(1);
 		}
 		xfree(acct_type);
@@ -1277,10 +1306,9 @@ extern void parse_command_line(int argc, char **argv)
 	field_count = list_count(print_fields_list);
 
 	if (optind < argc) {
-		debug2("Error: Unknown arguments:");
+		error("Unknown arguments:");
 		for (i=optind; i<argc; i++)
-			debug2(" %s", argv[i]);
-		debug2("\n");
+			error(" %s", argv[i]);
 		exit(1);
 	}
 	return;
@@ -1327,6 +1355,7 @@ extern void do_list(void)
 	ListIterator itr_step = NULL;
 	slurmdb_job_rec_t *job = NULL;
 	slurmdb_step_rec_t *step = NULL;
+	slurmdb_job_cond_t *job_cond = params.job_cond;
 
 	if (!jobs)
 		return;
@@ -1338,21 +1367,10 @@ extern void do_list(void)
 		    xstrcmp(params.cluster_name, job->cluster))
 			continue;
 
-
-		if (list_count(job->steps)) {
-			int cnt = list_count(job->steps);
-			job->stats.cpu_ave /= (double)cnt;
-			job->stats.rss_ave /= (double)cnt;
-			job->stats.vsize_ave /= (double)cnt;
-			job->stats.pages_ave /= (double)cnt;
-			job->stats.disk_read_ave /= (double)cnt;
-			job->stats.disk_write_ave /= (double)cnt;
-		}
-
 		if (job->show_full)
 			print_fields(JOB, job);
 
-		if (!params.opt_allocs
+		if (!(job_cond->flags & JOBCOND_FLAG_NO_STEP)
 		    && (job->track_steps || !job->show_full)) {
 			itr_step = list_iterator_create(job->steps);
 			while ((step = list_next(itr_step))) {
