@@ -7,11 +7,11 @@
  *  Written by Danny Auble <da@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -120,8 +120,9 @@ static int _set_cond(int *start, int argc, char **argv,
 					    MAX(command_len, 1))
 			   || !xstrncasecmp(argv[i], "Users",
 					    MAX(command_len, 1))) {
-			if (slurm_addto_char_list(assoc_cond->user_list,
-						 argv[i]+end))
+			if (slurm_addto_char_list_with_case(assoc_cond->user_list,
+							    argv[i]+end,
+							    user_case_norm))
 				u_set = 1;
 			else
 				exit_code=1;
@@ -253,7 +254,8 @@ static int _set_rec(int *start, int argc, char **argv,
 					 MAX(command_len, 1))) {
 			if (user->name)
 				xfree(user->name);
-			user->name = strip_quotes(argv[i]+end, NULL, 1);
+			user->name = strip_quotes(argv[i]+end, NULL,
+						  user_case_norm);
 			u_set = 1;
 		} else if (!xstrncasecmp(argv[i], "RawUsage",
 					 MAX(command_len, 7))) {
@@ -721,8 +723,9 @@ extern int sacctmgr_add_user(int argc, char **argv)
 		if (!end
 		   || !xstrncasecmp(argv[i], "Names", MAX(command_len, 1))
 		   || !xstrncasecmp(argv[i], "Users", MAX(command_len, 1))) {
-			if (!slurm_addto_char_list(assoc_cond->user_list,
-						 argv[i]+end))
+			if (!slurm_addto_char_list_with_case(assoc_cond->user_list,
+							     argv[i]+end,
+							     user_case_norm))
 				exit_code=1;
 		} else if (!xstrncasecmp(argv[i], "AdminLevel",
 					 MAX(command_len, 2))) {
@@ -1972,7 +1975,9 @@ extern int sacctmgr_delete_user(int argc, char **argv)
 				if (!del_user_list)
 					del_user_list = list_create(
 						slurm_destroy_char);
-				slurm_addto_char_list(del_user_list, tmp);
+				slurm_addto_char_list_with_case(del_user_list,
+								tmp,
+								user_case_norm);
 			}
 		}
 		list_iterator_destroy(itr);
@@ -2022,8 +2027,9 @@ extern int sacctmgr_delete_user(int argc, char **argv)
 						       "...\n");
 					}
 					printf("  %s\n", user->name);
-					slurm_addto_char_list(del_user_list,
-							      user->name);
+					slurm_addto_char_list_with_case(del_user_list,
+									user->name,
+									user_case_norm);
 				}
 				list_iterator_destroy(itr);
 				FREE_NULL_LIST(user_list);
