@@ -1,14 +1,14 @@
 /*****************************************************************************\
  *  info_burst_buffer.c - Burst buffer information functions for scontrol.
  *****************************************************************************
- *  Copyright (C) 2014 SchedMD LLC <https://www.schedmd.com/>.
+ *  Copyright (C) 2014-2017 SchedMD LLC <https://www.schedmd.com/>.
  *  Written by Morris Jette <jette@schedmd.com>
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -24,18 +24,37 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
 #include "scontrol.h"
 
+/*
+ * scontrol_print_bbstat - Print burst buffer status information to stdout
+ */
+extern void scontrol_print_bbstat(int argc, char **argv)
+{
+	char *stat_resp = NULL;
+	int error_code;
+
+	error_code = slurm_load_burst_buffer_stat(argc, argv, &stat_resp);
+	if (error_code) {
+		exit_code = 1;
+		if (quiet_flag != 1)
+			slurm_perror("slurm_load_burst_buffer_stat error");
+		return;
+	}
+	fprintf(stdout, "%s", stat_resp);
+	xfree(stat_resp);
+}
+
 /*
  * scontrol_print_burst_buffer - print all burst_buffer information to stdout
  */
@@ -49,7 +68,7 @@ extern void scontrol_print_burst_buffer(void)
 	if (error_code) {
 		exit_code = 1;
 		if (quiet_flag != 1)
-			slurm_perror ("slurm_load_burst_buffer error");
+			slurm_perror ("slurm_load_burst_buffer_info error");
 		return;
 	}
 
