@@ -8,11 +8,11 @@
  *  Written by Joey Ekstrom <ekstrom1@llnl.gov>, Morris Jette <jette1@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -28,13 +28,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -66,8 +66,6 @@ typedef struct load_info_struct {
 
 struct sinfo_parameters params;
 
-static int g_node_scaling = 1;
-
 static int sinfo_cnt;	/* thread count */
 static pthread_mutex_t sinfo_cnt_mutex = PTHREAD_MUTEX_INITIALIZER;
 static pthread_cond_t  sinfo_cnt_cond  = PTHREAD_COND_INITIALIZER;
@@ -76,24 +74,18 @@ static pthread_mutex_t sinfo_list_mutex = PTHREAD_MUTEX_INITIALIZER;
 /*************
  * Functions *
  *************/
-static int  _bg_report(block_info_msg_t *block_ptr);
 void *      _build_part_info(void *args);
 static int  _build_sinfo_data(List sinfo_list,
 			      partition_info_msg_t *partition_msg,
 			      node_info_msg_t *node_msg);
 static sinfo_data_t *_create_sinfo(partition_info_t* part_ptr,
-				   uint16_t part_inx, node_info_t *node_ptr,
-				   uint32_t node_scaling);
+				   uint16_t part_inx, node_info_t *node_ptr);
 static int  _find_part_list(void *x, void *key);
 static bool _filter_out(node_info_t *node_ptr);
 static int  _get_info(bool clear_old, slurmdb_federation_rec_t *fed);
-static int  _handle_subgrps(List sinfo_list, uint16_t part_num,
-			    partition_info_t *part_ptr,
-			    node_info_t *node_ptr, uint32_t node_scaling);
 static int  _insert_node_ptr(List sinfo_list, uint16_t part_num,
 			     partition_info_t *part_ptr,
-			     node_info_t *node_ptr, uint32_t node_scaling);
-static int  _load_blocks(block_info_msg_t **block_pptr, bool clear_old);
+			     node_info_t *node_ptr);
 static int  _load_resv(reserve_info_msg_t ** reserv_pptr, bool clear_old);
 static bool _match_node_data(sinfo_data_t *sinfo_ptr, node_info_t *node_ptr);
 static bool _match_part_data(sinfo_data_t *sinfo_ptr,
@@ -109,8 +101,7 @@ static int  _reservation_report(reserve_info_msg_t *resv_ptr);
 static bool _serial_part_data(void);
 static void _sinfo_list_delete(void *data);
 static void _sort_hostlist(List sinfo_list);
-static void _update_sinfo(sinfo_data_t *sinfo_ptr, node_info_t *node_ptr,
-			  uint32_t node_scaling);
+static void _update_sinfo(sinfo_data_t *sinfo_ptr, node_info_t *node_ptr);
 
 int main(int argc, char **argv)
 {
@@ -173,19 +164,10 @@ static int _multi_cluster(List clusters)
 static int _get_info(bool clear_old, slurmdb_federation_rec_t *fed)
 {
 	List node_info_msg_list = NULL, part_info_msg_list = NULL;
-	block_info_msg_t *block_msg = NULL;
 	reserve_info_msg_t *reserv_msg = NULL;
 	List sinfo_list = NULL;
 	int rc = SLURM_SUCCESS;
 
-	if (params.bg_flag) {
-		if (_load_blocks(&block_msg, clear_old))
-			rc = SLURM_ERROR;
-		else
-			(void) _bg_report(block_msg);
-		return rc;
-	}
-
 	if (params.reservation_flag) {
 		if (_load_resv(&reserv_msg, clear_old))
 			rc = SLURM_ERROR;
@@ -215,38 +197,6 @@ static int _get_info(bool clear_old, slurmdb_federation_rec_t *fed)
 	return SLURM_SUCCESS;
 }
 
-/*
- * _bg_report - download and print current bgblock state information
- */
-static int _bg_report(block_info_msg_t *block_ptr)
-{
-	int i;
-
-	if (!block_ptr) {
-		slurm_perror("No block_ptr given");
-		return SLURM_ERROR;
-	}
-
-	if (!params.no_header)
-		printf("BG_BLOCK         MIDPLANES       STATE    CONNECTION USE\n");
-/*                      1234567890123456 123456789012 12345678 1234567890 12345+ */
-/*                      RMP_22Apr1544018 bg[123x456]  READY    TORUS      COPROCESSOR */
-
-	for (i = 0; i < block_ptr->record_count; i++) {
-		char *conn_str = conn_type_string_full(
-			block_ptr->block_array[i].conn_type);
-		printf("%-16.16s %-15.15s %-8.8s %-10.10s %s\n",
-		       block_ptr->block_array[i].bg_block_id,
-		       block_ptr->block_array[i].mp_str,
-		       bg_block_state_string(block_ptr->block_array[i].state),
-		       conn_str,
-		       node_use_string(block_ptr->block_array[i].node_use));
-		xfree(conn_str);
-	}
-
-	return SLURM_SUCCESS;
-}
-
 /*
  * _reservation_report - print current reservation information
  */
@@ -263,51 +213,6 @@ static int _reservation_report(reserve_info_msg_t *resv_ptr)
 	return SLURM_SUCCESS;
 }
 
-/*
- * _load_blocks - download the current server's BlueGene block data state
- * block_pptr IN/OUT - BlueGene block data
- * clear_old IN - If set, then always replace old data, needed when going
- *		  between clusters.
- * RET zero or error code
- */
-static int _load_blocks(block_info_msg_t **block_pptr, bool clear_old)
-{
-	static block_info_msg_t *old_bg_ptr = NULL, *new_bg_ptr;
-	uint16_t show_flags = 0;
-	int error_code = SLURM_SUCCESS;
-
-	if (params.all_flag)
-		show_flags |= SHOW_ALL;
-
-	if (params.cluster_flags & CLUSTER_FLAG_BG) {
-		if (old_bg_ptr) {
-			if (clear_old)
-				old_bg_ptr->last_update = 0;
-			error_code = slurm_load_block_info(
-				old_bg_ptr->last_update,
-				&new_bg_ptr, show_flags);
-			if (error_code == SLURM_SUCCESS)
-				slurm_free_block_info_msg(old_bg_ptr);
-			else if (slurm_get_errno() == SLURM_NO_CHANGE_IN_DATA) {
-				error_code = SLURM_SUCCESS;
-				new_bg_ptr = old_bg_ptr;
-			}
-		} else {
-			error_code = slurm_load_block_info((time_t) NULL,
-							   &new_bg_ptr,
-							   show_flags);
-		}
-	}
-
-	if (error_code) {
-		slurm_perror("slurm_load_block");
-		return error_code;
-	}
-	old_bg_ptr = new_bg_ptr;
-	*block_pptr = new_bg_ptr;
-	return SLURM_SUCCESS;
-}
-
 /*
  * _load_resv - download the current server's reservation state
  * reserv_pptr IN/OUT - reservation information message
@@ -423,34 +328,15 @@ static List _query_server(bool clear_old)
 			/* don't worry about mixed since the
 			 * whole node is being drained. */
 		} else {
-			uint16_t alloc_cpus = 0, err_cpus = 0, idle_cpus;
-			int single_node_cpus =
-				(node_ptr->cpus / g_node_scaling);
+			uint16_t alloc_cpus = 0, idle_cpus;
 
 			select_g_select_nodeinfo_get(node_ptr->select_nodeinfo,
 						     SELECT_NODEDATA_SUBCNT,
 						     NODE_STATE_ALLOCATED,
 						     &alloc_cpus);
-			if (params.cluster_flags & CLUSTER_FLAG_BG) {
-				if (!alloc_cpus &&
-				    (IS_NODE_ALLOCATED(node_ptr) ||
-				     IS_NODE_COMPLETING(node_ptr)))
-					alloc_cpus = node_ptr->cpus;
-				else
-					alloc_cpus *= single_node_cpus;
-			}
 			idle_cpus = node_ptr->cpus - alloc_cpus;
 
-			select_g_select_nodeinfo_get(node_ptr->select_nodeinfo,
-						     SELECT_NODEDATA_SUBCNT,
-						     NODE_STATE_ERROR,
-						     &err_cpus);
-			if (params.cluster_flags & CLUSTER_FLAG_BG)
-				err_cpus *= single_node_cpus;
-			idle_cpus -= err_cpus;
-
-			if ((alloc_cpus && err_cpus) ||
-			    (idle_cpus  && (idle_cpus != node_ptr->cpus))) {
+			if (idle_cpus && (idle_cpus != node_ptr->cpus)) {
 				node_ptr->node_state &= NODE_STATE_FLAGS;
 				node_ptr->node_state |= NODE_STATE_MIXED;
 			}
@@ -511,34 +397,15 @@ static void *_load_job_prio_thread(void *args)
 			/* don't worry about mixed since the
 			 * whole node is being drained. */
 		} else {
-			uint16_t alloc_cpus = 0, err_cpus = 0, idle_cpus;
-			int single_node_cpus =
-				(node_ptr->cpus / g_node_scaling);
+			uint16_t alloc_cpus = 0, idle_cpus;
 
 			select_g_select_nodeinfo_get(node_ptr->select_nodeinfo,
 						     SELECT_NODEDATA_SUBCNT,
 						     NODE_STATE_ALLOCATED,
 						     &alloc_cpus);
-			if (params.cluster_flags & CLUSTER_FLAG_BG) {
-				if (!alloc_cpus &&
-				    (IS_NODE_ALLOCATED(node_ptr) ||
-				     IS_NODE_COMPLETING(node_ptr)))
-					alloc_cpus = node_ptr->cpus;
-				else
-					alloc_cpus *= single_node_cpus;
-			}
 			idle_cpus = node_ptr->cpus - alloc_cpus;
 
-			select_g_select_nodeinfo_get(node_ptr->select_nodeinfo,
-						     SELECT_NODEDATA_SUBCNT,
-						     NODE_STATE_ERROR,
-						     &err_cpus);
-			if (params.cluster_flags & CLUSTER_FLAG_BG)
-				err_cpus *= single_node_cpus;
-			idle_cpus -= err_cpus;
-
-			if ((alloc_cpus && err_cpus) ||
-			    (idle_cpus  && (idle_cpus != node_ptr->cpus))) {
+			if (idle_cpus && (idle_cpus != node_ptr->cpus)) {
 				node_ptr->node_state &= NODE_STATE_FLAGS;
 				node_ptr->node_state |= NODE_STATE_MIXED;
 			}
@@ -630,7 +497,6 @@ void *_build_part_info(void *args)
 
 	while (part_ptr->node_inx[j] >= 0) {
 		int i = 0;
-		uint16_t subgrp_size = 0;
 		for (i = part_ptr->node_inx[j];
 		     i <= part_ptr->node_inx[j+1]; i++) {
 			if (i >= node_msg->record_count) {
@@ -641,19 +507,8 @@ void *_build_part_info(void *args)
 			if (node_ptr->name == NULL)
 				continue;
 
-			if (select_g_select_nodeinfo_get(
-				   node_ptr->select_nodeinfo,
-				   SELECT_NODEDATA_SUBGRP_SIZE, 0,
-				   &subgrp_size) == SLURM_SUCCESS
-			    && subgrp_size) {
-				_handle_subgrps(sinfo_list, part_num,
-						part_ptr, node_ptr,
-						node_msg->node_scaling);
-			} else {
-				_insert_node_ptr(sinfo_list, part_num,
-						 part_ptr, node_ptr,
-						 node_msg->node_scaling);
-			}
+			_insert_node_ptr(sinfo_list, part_num,
+					 part_ptr, node_ptr);
 		}
 		j += 2;
 	}
@@ -690,8 +545,6 @@ static int _build_sinfo_data(List sinfo_list,
 	partition_info_t *part_ptr = NULL;
 	int j;
 
-	g_node_scaling = node_msg->node_scaling;
-
 	/* by default every partition is shown, even if no nodes */
 	if ((!params.node_flag) && params.match_flags.partition_flag) {
 		part_ptr = partition_msg->partition_array;
@@ -702,8 +555,7 @@ static int _build_sinfo_data(List sinfo_list,
 					     part_ptr->name))) {
 				list_append(sinfo_list, _create_sinfo(
 						    part_ptr, (uint16_t) j,
-						    NULL,
-						    node_msg->node_scaling));
+						    NULL));
 			}
 		}
 	}
@@ -727,7 +579,6 @@ static int _build_sinfo_data(List sinfo_list,
 
 		if (node_msg->record_count == 1) { /* node_name_single */
 			int pos = -1;
-			uint16_t subgrp_size = 0;
 			hostlist_t hl;
 
 			node_ptr = &(node_msg->node_array[0]);
@@ -739,26 +590,8 @@ static int _build_sinfo_data(List sinfo_list,
 			hostlist_destroy(hl);
 			if (pos < 0)
 				continue;
-			if (select_g_select_nodeinfo_get(
-				   node_ptr->select_nodeinfo,
-				   SELECT_NODEDATA_SUBGRP_SIZE,
-				   0,
-				   &subgrp_size) == SLURM_SUCCESS
-			    && subgrp_size) {
-				_handle_subgrps(sinfo_list,
-						(uint16_t) j,
-						part_ptr,
-						node_ptr,
-						node_msg->
-						node_scaling);
-			} else {
-				_insert_node_ptr(sinfo_list,
-						 (uint16_t) j,
-						 part_ptr,
-						 node_ptr,
-						 node_msg->
-						 node_scaling);
-			}
+			_insert_node_ptr(sinfo_list, (uint16_t) j,
+					 part_ptr, node_ptr);
 			continue;
 		}
 
@@ -847,27 +680,12 @@ static bool _filter_out(node_info_t *node_ptr)
 					match = true;
 					break;
 				}
-			} else if (*node_state == NODE_STATE_ERROR) {
-				slurm_get_select_nodeinfo(
-					node_ptr->select_nodeinfo,
-					SELECT_NODEDATA_SUBCNT,
-					NODE_STATE_ERROR,
-					&cpus);
-				if (cpus) {
-					match = true;
-					break;
-				}
 			} else if (*node_state == NODE_STATE_ALLOCATED) {
 				slurm_get_select_nodeinfo(
 					node_ptr->select_nodeinfo,
 					SELECT_NODEDATA_SUBCNT,
 					NODE_STATE_ALLOCATED,
 					&cpus);
-				if (params.cluster_flags & CLUSTER_FLAG_BG
-				    && !cpus &&
-				    (IS_NODE_ALLOCATED(node_ptr) ||
-				     IS_NODE_COMPLETING(node_ptr)))
-					cpus = node_ptr->cpus;
 				if (cpus) {
 					match = true;
 					break;
@@ -1101,16 +919,12 @@ static bool _match_part_data(sinfo_data_t *sinfo_ptr,
 	return true;
 }
 
-static void _update_sinfo(sinfo_data_t *sinfo_ptr, node_info_t *node_ptr,
-			  uint32_t node_scaling)
+static void _update_sinfo(sinfo_data_t *sinfo_ptr, node_info_t *node_ptr)
 {
 	uint32_t base_state;
 	uint64_t alloc_mem = 0;
-	uint16_t used_cpus = 0, error_cpus = 0;
-	int total_cpus = 0, total_nodes = 0;
-	/* since node_scaling could be less here, we need to use the
-	 * global node scaling which should never change. */
-	int single_node_cpus = (node_ptr->cpus / g_node_scaling);
+	uint16_t used_cpus = 0;
+	int total_cpus = 0;
 
 	base_state = node_ptr->node_state & NODE_STATE_BASE;
 
@@ -1205,83 +1019,34 @@ static void _update_sinfo(sinfo_data_t *sinfo_ptr, node_info_t *node_ptr,
 		hostlist_push_host(sinfo_ptr->hostnames, node_ptr->node_hostname);
 
 	total_cpus = node_ptr->cpus;
-	total_nodes = node_scaling;
 
 	select_g_select_nodeinfo_get(node_ptr->select_nodeinfo,
 				     SELECT_NODEDATA_SUBCNT,
 				     NODE_STATE_ALLOCATED,
 				     &used_cpus);
-	select_g_select_nodeinfo_get(node_ptr->select_nodeinfo,
-				     SELECT_NODEDATA_SUBCNT,
-				     NODE_STATE_ERROR,
-				     &error_cpus);
 	select_g_select_nodeinfo_get(node_ptr->select_nodeinfo,
 				     SELECT_NODEDATA_MEM_ALLOC,
 				     NODE_STATE_ALLOCATED,
 				     &alloc_mem);
 
-	if (params.cluster_flags & CLUSTER_FLAG_BG) {
-		if (!params.match_flags.state_flag &&
-		    (used_cpus || error_cpus)) {
-			/* We only get one shot at this (because all states
-			 * are combined together), so we need to make
-			 * sure we get all the subgrps accounted. (So use
-			 * g_node_scaling for safe measure) */
-			total_nodes = g_node_scaling;
+	if ((base_state == NODE_STATE_ALLOCATED) ||
+	    (base_state == NODE_STATE_MIXED) ||
+	    IS_NODE_COMPLETING(node_ptr))
+		sinfo_ptr->nodes_alloc++;
+	else if (IS_NODE_DRAIN(node_ptr)
+		 || (base_state == NODE_STATE_DOWN))
+		sinfo_ptr->nodes_other++;
+	else
+		sinfo_ptr->nodes_idle++;
 
-			sinfo_ptr->nodes_alloc += used_cpus;
-			sinfo_ptr->nodes_other += error_cpus;
-			sinfo_ptr->nodes_idle +=
-				(total_nodes - (used_cpus + error_cpus));
-			used_cpus  *= single_node_cpus;
-			error_cpus *= single_node_cpus;
-		} else {
-			/* process only for this subgrp and then return */
-			total_cpus = total_nodes * single_node_cpus;
-
-			if ((base_state == NODE_STATE_ALLOCATED) ||
-			    (base_state == NODE_STATE_MIXED) ||
-			    (node_ptr->node_state & NODE_STATE_COMPLETING)) {
-				sinfo_ptr->nodes_alloc += total_nodes;
-				sinfo_ptr->cpus_alloc += total_cpus;
-			} else if (IS_NODE_DRAIN(node_ptr) ||
-				   (base_state == NODE_STATE_DOWN)) {
-				sinfo_ptr->nodes_other += total_nodes;
-				sinfo_ptr->cpus_other += total_cpus;
-			} else {
-				sinfo_ptr->nodes_idle += total_nodes;
-				sinfo_ptr->cpus_idle += total_cpus;
-			}
-
-			sinfo_ptr->nodes_total += total_nodes;
-			sinfo_ptr->cpus_total += total_cpus;
-
-			return;
-		}
-	} else {
-		if ((base_state == NODE_STATE_ALLOCATED) ||
-		    (base_state == NODE_STATE_MIXED) ||
-		    IS_NODE_COMPLETING(node_ptr))
-			sinfo_ptr->nodes_alloc += total_nodes;
-		else if (IS_NODE_DRAIN(node_ptr)
-			 || (base_state == NODE_STATE_DOWN))
-			sinfo_ptr->nodes_other += total_nodes;
-		else
-			sinfo_ptr->nodes_idle += total_nodes;
-	}
-
-	sinfo_ptr->nodes_total += total_nodes;
+	sinfo_ptr->nodes_total++;
 
 	sinfo_ptr->cpus_alloc += used_cpus;
 	sinfo_ptr->cpus_total += total_cpus;
-	total_cpus -= used_cpus + error_cpus;
+	total_cpus -= used_cpus;
 	sinfo_ptr->alloc_memory = alloc_mem;
 
-	if (error_cpus) {
-		sinfo_ptr->cpus_idle += total_cpus;
-		sinfo_ptr->cpus_other += error_cpus;
-	} else if (IS_NODE_DRAIN(node_ptr) ||
-		   (base_state == NODE_STATE_DOWN)) {
+	if (IS_NODE_DRAIN(node_ptr) || (base_state == NODE_STATE_DOWN)) {
 		sinfo_ptr->cpus_other += total_cpus;
 	} else
 		sinfo_ptr->cpus_idle += total_cpus;
@@ -1289,23 +1054,12 @@ static void _update_sinfo(sinfo_data_t *sinfo_ptr, node_info_t *node_ptr,
 
 static int _insert_node_ptr(List sinfo_list, uint16_t part_num,
 			    partition_info_t *part_ptr,
-			    node_info_t *node_ptr, uint32_t node_scaling)
+			    node_info_t *node_ptr)
 {
 	int rc = SLURM_SUCCESS;
 	sinfo_data_t *sinfo_ptr = NULL;
 	ListIterator itr = NULL;
 
-	if (params.cluster_flags & CLUSTER_FLAG_BG) {
-		uint16_t error_cpus = 0;
-		select_g_select_nodeinfo_get(node_ptr->select_nodeinfo,
-					     SELECT_NODEDATA_SUBCNT,
-					     NODE_STATE_ERROR,
-					     &error_cpus);
-
-		if (error_cpus && !node_ptr->reason)
-			node_ptr->reason = xstrdup("Block(s) in error state");
-	}
-
 	itr = list_iterator_create(sinfo_list);
 	while ((sinfo_ptr = list_next(itr))) {
 		if (!_match_part_data(sinfo_ptr, part_ptr))
@@ -1313,7 +1067,7 @@ static int _insert_node_ptr(List sinfo_list, uint16_t part_num,
 		if (sinfo_ptr->nodes_total &&
 		    (!_match_node_data(sinfo_ptr, node_ptr)))
 			continue;
-		_update_sinfo(sinfo_ptr, node_ptr, node_scaling);
+		_update_sinfo(sinfo_ptr, node_ptr);
 		break;
 	}
 	list_iterator_destroy(itr);
@@ -1321,87 +1075,12 @@ static int _insert_node_ptr(List sinfo_list, uint16_t part_num,
 	/* if no match, create new sinfo_data entry */
 	if (!sinfo_ptr) {
 		list_append(sinfo_list,
-			    _create_sinfo(part_ptr, part_num,
-					  node_ptr, node_scaling));
+			    _create_sinfo(part_ptr, part_num, node_ptr));
 	}
 
 	return rc;
 }
 
-static int _handle_subgrps(List sinfo_list, uint16_t part_num,
-			   partition_info_t *part_ptr,
-			   node_info_t *node_ptr, uint32_t node_scaling)
-{
-	uint16_t size;
-	int *node_state;
-	int i=0, state_cnt = 2;
-	ListIterator iterator = NULL;
-	enum node_states state[] =
-		{ NODE_STATE_ALLOCATED, NODE_STATE_ERROR };
-
-	/* If we ever update the hostlist stuff to support this stuff
-	 * then we can use this to tack on the end of the node name
-	 * the subgrp stuff.  On bluegene systems this would be nice
-	 * to see the ionodes in certain states.
-	 * When asking for nodes that are reserved, we need to return
-	 * all states of those nodes.
-	 */
-	if (params.state_list)
-		iterator = list_iterator_create(params.state_list);
-
-	for(i=0; i<state_cnt; i++) {
-		if (iterator) {
-			node_info_t tmp_node, *tmp_node_ptr = &tmp_node;
-			while ((node_state = list_next(iterator))) {
-				tmp_node_ptr->node_state = *node_state;
-				if ((((state[i] == NODE_STATE_ALLOCATED)
-				      && IS_NODE_DRAINING(tmp_node_ptr))
-				     || (*node_state == NODE_STATE_DRAIN))
-				     || (*node_state == state[i])
-				     || (*node_state == NODE_STATE_RES))
-					break;
-			}
-			list_iterator_reset(iterator);
-			if (!node_state)
-				continue;
-		}
-		if (select_g_select_nodeinfo_get(node_ptr->select_nodeinfo,
-						SELECT_NODEDATA_SUBCNT,
-						state[i],
-						&size) == SLURM_SUCCESS
-		   && size) {
-			node_scaling -= size;
-			node_ptr->node_state &= NODE_STATE_FLAGS;
-			node_ptr->node_state |= state[i];
-			_insert_node_ptr(sinfo_list, part_num, part_ptr,
-					 node_ptr, size);
-		}
-	}
-
-	/* now handle the idle */
-	if (iterator) {
-		while ((node_state = list_next(iterator))) {
-			node_info_t tmp_node, *tmp_node_ptr = &tmp_node;
-			tmp_node_ptr->node_state = *node_state;
-			if (((*node_state == NODE_STATE_DRAIN)
-			     || IS_NODE_DRAINED(tmp_node_ptr))
-			     || (*node_state == NODE_STATE_IDLE)
-			     || (*node_state == NODE_STATE_RES))
-				break;
-		}
-		list_iterator_destroy(iterator);
-		if (!node_state)
-			return SLURM_SUCCESS;
-	}
-	node_ptr->node_state &= NODE_STATE_FLAGS;
-	node_ptr->node_state |= NODE_STATE_IDLE;
-	if ((int)node_scaling > 0)
-		_insert_node_ptr(sinfo_list, part_num, part_ptr,
-				 node_ptr, node_scaling);
-
-	return SLURM_SUCCESS;
-}
-
 /*
  * _create_sinfo - create an sinfo record for the given node and partition
  * sinfo_list IN/OUT - table of accumulated sinfo records
@@ -1410,8 +1089,7 @@ static int _handle_subgrps(List sinfo_list, uint16_t part_num,
  * node_ptr IN       - pointer to node record to add
  */
 static sinfo_data_t *_create_sinfo(partition_info_t* part_ptr,
-				   uint16_t part_inx, node_info_t *node_ptr,
-				   uint32_t node_scaling)
+				   uint16_t part_inx, node_info_t *node_ptr)
 {
 	sinfo_data_t *sinfo_ptr;
 	/* create an entry */
@@ -1424,7 +1102,7 @@ static sinfo_data_t *_create_sinfo(partition_info_t* part_ptr,
 	sinfo_ptr->hostnames = hostlist_create(NULL);
 
 	if (node_ptr)
-		_update_sinfo(sinfo_ptr, node_ptr, node_scaling);
+		_update_sinfo(sinfo_ptr, node_ptr);
 
 	return sinfo_ptr;
 }
