@@ -4,11 +4,11 @@
  *  Copyright (C) 2014-2015 SchedMD LLC.
  *  Written by Morris Jette <jette@schedmd.com>
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -24,13 +24,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -59,6 +59,7 @@
 typedef struct slurm_bb_ops {
 	uint64_t	(*get_system_size)	(void);
 	int		(*load_state)	(bool init_config);
+	char *		(*get_status)	(uint32_t argc, char **argv);
 	int		(*state_pack)	(uid_t uid, Buf buffer,
 					 uint16_t protocol_version);
 	int		(*reconfig)	(void);
@@ -87,6 +88,7 @@ typedef struct slurm_bb_ops {
 static const char *syms[] = {
 	"bb_p_get_system_size",
 	"bb_p_load_state",
+	"bb_p_get_status",
 	"bb_p_state_pack",
 	"bb_p_reconfig",
 	"bb_p_job_validate",
@@ -114,7 +116,7 @@ static bool init_run = false;
 /*
  * Initialize the burst buffer infrastructure.
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int bb_g_init(void)
 {
@@ -172,7 +174,7 @@ fini:
 /*
  * Terminate the burst buffer infrastructure. Free memory.
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int bb_g_fini(void)
 {
@@ -212,7 +214,7 @@ fini:	slurm_mutex_unlock(&g_context_lock);
  * etc.).
  *
  * init_config IN - true if called as part of slurmctld initialization
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int bb_g_load_state(bool init_config)
 {
@@ -232,11 +234,41 @@ extern int bb_g_load_state(bool init_config)
 	return rc;
 }
 
+/*
+ * Return string containing current burst buffer status
+ * argc IN - count of status command arguments
+ * argv IN - status command arguments
+ * RET status string, release memory using xfree()
+ */
+extern char *bb_g_get_status(uint32_t argc, char **argv)
+{
+	DEF_TIMERS;
+	int i;
+	char *status = NULL, *tmp;
+
+	START_TIMER;
+	(void) bb_g_init();
+	slurm_mutex_lock(&g_context_lock);
+	for (i = 0; i < g_context_cnt; i++) {
+		tmp = (*(ops[i].get_status))(argc, argv);
+		if (status) {
+			xstrcat(status, tmp);
+			xfree(tmp);
+		} else {
+			status = tmp;
+		}
+	}
+	slurm_mutex_unlock(&g_context_lock);
+	END_TIMER2(__func__);
+
+	return status;
+}
+
 /*
  * Pack current burst buffer state information for network transmission to
  * user (e.g. "scontrol show burst")
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int bb_g_state_pack(uid_t uid, Buf buffer, uint16_t protocol_version)
 {
@@ -272,7 +304,7 @@ extern int bb_g_state_pack(uid_t uid, Buf buffer, uint16_t protocol_version)
 /*
  * Note configuration may have changed. Handle changes in BurstBufferParameters.
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int bb_g_reconfig(void)
 {
@@ -326,7 +358,7 @@ extern uint64_t bb_g_get_system_size(char *name)
  *
  * job_desc IN - Job submission request
  * submit_uid IN - ID of the user submitting the job.
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int bb_g_job_validate(struct job_descriptor *job_desc,
 			     uid_t submit_uid)
@@ -351,7 +383,7 @@ extern int bb_g_job_validate(struct job_descriptor *job_desc,
  * Secondary validation of a job submit request with respect to burst buffer
  * options. Performed after establishing job ID and creating script file.
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int bb_g_job_validate2(struct job_record *job_ptr, char **err_msg)
 {
@@ -506,7 +538,7 @@ extern time_t bb_g_job_get_est_start(struct job_record *job_ptr)
  * Allocate burst buffers to jobs expected to start soonest
  * Job records must be read locked
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int bb_g_job_try_stage_in(void)
 {
@@ -579,7 +611,7 @@ extern int bb_g_job_test_stage_in(struct job_record *job_ptr, bool test_only)
  * At this time, bb_g_job_test_stage_in() should have been run sucessfully AND
  * the compute nodes selected for the job.
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int bb_g_job_begin(struct job_record *job_ptr)
 {
@@ -605,7 +637,7 @@ extern int bb_g_job_begin(struct job_record *job_ptr)
  * Executed after bb_g_job_begin() if there was an allocation failure.
  * Does not release previously allocated resources.
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int bb_g_job_revoke_alloc(struct job_record *job_ptr)
 {
@@ -630,7 +662,7 @@ extern int bb_g_job_revoke_alloc(struct job_record *job_ptr)
 /*
  * Trigger a job's burst buffer stage-out to begin
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int bb_g_job_start_stage_out(struct job_record *job_ptr)
 {
@@ -720,7 +752,7 @@ extern int bb_g_job_test_stage_out(struct job_record *job_ptr)
 /*
  * Terminate any file staging and completely release burst buffer resources
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int bb_g_job_cancel(struct job_record *job_ptr)
 {
