@@ -9,11 +9,11 @@
  *  Derived from dsh written by Jim Garlick <garlick1@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -29,13 +29,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -89,6 +89,11 @@ extern bool deadline_ok(struct job_record *job_ptr, char *func);
  */
 extern void epilog_slurmctld(struct job_record *job_ptr);
 
+/*
+ * Delete a record from a job's feature_list
+ */
+extern void feature_list_delete(void *x);
+
 /*
  * job_is_completing - Determine if jobs are in the process of completing.
  * IN/OUT  eff_cg_bitmap - optional bitmap of all relevent completing nodes,
@@ -126,13 +131,15 @@ extern int make_batch_job_cred(batch_job_launch_msg_t *launch_msg_ptr,
 			       struct job_record *job_ptr,
 			       uint16_t protocol_version);
 
-/* Determine which nodes must be rebooted for a job
+/*
+ * Determine which nodes must be rebooted for a job
  * IN job_ptr - pointer to job that will be initiated
- * RET bitmap of nodes requiring a reboot
+ * RET bitmap of nodes requiring a reboot for NodeFeaturesPlugin or NULL if none
  */
 extern bitstr_t *node_features_reboot(struct job_record *job_ptr);
 
-/* Determine if node boot required for this job
+/*
+ * Determine if node boot required for this job
  * IN job_ptr - pointer to job that will be initiated
  * IN node_bitmap - nodes to be allocated
  * RET - true if reboot required
