@@ -7,11 +7,11 @@
  *  Written by Morris Jette <jette1@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -47,14 +47,14 @@
 /*
  * Initialize the preemption plugin.
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 int slurm_preempt_init(void);
 
 /*
  * Terminate the preemption plugin.
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int slurm_preempt_fini(void);
 
@@ -90,8 +90,8 @@ extern bool slurm_job_preempt_check(job_queue_rec_t *preemptor,
 				    job_queue_rec_t *preemptee);
 
 
-/* Returns a SLURM errno if preempt grace isn't allowed */
+/* Returns a Slurm errno if preempt grace isn't allowed */
 extern int slurm_job_check_grace(struct job_record *job_ptr,
-				 uint32_t preemptor);
+				 struct job_record *preemptor_ptr);
 
 #endif /*__SLURM_CONTROLLER_PREEMPT_H__*/
