@@ -386,6 +386,7 @@ static int _build_bitmaps(void)
 
 	/* initialize the idle and up bitmaps */
 	FREE_NULL_BITMAP(avail_node_bitmap);
+	FREE_NULL_BITMAP(bf_ignore_node_bitmap);
 	FREE_NULL_BITMAP(booting_node_bitmap);
 	FREE_NULL_BITMAP(cg_node_bitmap);
 	FREE_NULL_BITMAP(future_node_bitmap);
@@ -395,6 +396,7 @@ static int _build_bitmaps(void)
 	FREE_NULL_BITMAP(up_node_bitmap);
 	FREE_NULL_BITMAP(rs_node_bitmap);
 	avail_node_bitmap = (bitstr_t *) bit_alloc(node_record_count);
+	bf_ignore_node_bitmap = bit_alloc(node_record_count);
 	booting_node_bitmap = (bitstr_t *) bit_alloc(node_record_count);
 	cg_node_bitmap    = (bitstr_t *) bit_alloc(node_record_count);
 	future_node_bitmap = (bitstr_t *) bit_alloc(node_record_count);
@@ -432,7 +434,7 @@ static int _build_bitmaps(void)
 		if (IS_NODE_IDLE(node_ptr) || IS_NODE_ALLOCATED(node_ptr)) {
 			if ((drain_flag == 0) &&
 			    (!IS_NODE_NO_RESPOND(node_ptr)))
-				bit_set(avail_node_bitmap, i);
+				make_node_avail(i);
 			bit_set(up_node_bitmap, i);
 		}
 		if (IS_NODE_POWER_SAVE(node_ptr))
@@ -1698,7 +1700,7 @@ static void _gres_reconfig(bool reconfig)
 	struct node_record *node_ptr;
 	char *gres_name;
 	bool gres_changed;
-	int i;
+	int i, total_threads, total_cores;
 
 	if (reconfig) {
 		gres_plugin_reconfig(&gres_changed);
@@ -1711,6 +1713,27 @@ static void _gres_reconfig(bool reconfig)
 				gres_name = node_ptr->config_ptr->gres;
 			gres_plugin_init_node_config(node_ptr->name, gres_name,
 						     &node_ptr->gres_list);
+			if (!IS_NODE_CLOUD(node_ptr))
+				continue;
+
+			/*
+			 * Load in gres for node now. By default Slurm gets this
+			 * information when the node registers for the first
+			 * time, which can take a while for a node in the cloud
+			 * to boot.
+			 */
+			gres_plugin_node_config_load(
+				node_ptr->config_ptr->cpus, node_ptr->name,
+				NULL);
+			total_cores = node_ptr->config_ptr->sockets *
+				node_ptr->config_ptr->cores;
+			total_threads = total_cores *
+				node_ptr->config_ptr->threads;
+			gres_plugin_node_config_validate(
+				node_ptr->name, node_ptr->config_ptr->gres,
+				&node_ptr->gres, &node_ptr->gres_list,
+				total_threads, total_cores,
+				slurmctld_conf.fast_schedule, NULL);
 		}
 	}
 }
