@@ -6,11 +6,11 @@
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Morris Jette <jette1@llnl.gov>.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -26,13 +26,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -149,7 +149,7 @@ extern int slurm_proctrack_fini(void)
  * job->cont_id OUT - Plugin must fill in job->cont_id either here
  *                    or in proctrack_g_add()
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int proctrack_g_create(stepd_step_rec_t * job)
 {
@@ -166,7 +166,7 @@ extern int proctrack_g_create(stepd_step_rec_t * job)
  * job->cont_id OUT - Plugin must fill in job->cont_id either here
  *                    or in proctrack_g_create()
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int proctrack_g_add(stepd_step_rec_t * job, pid_t pid)
 {
@@ -288,34 +288,59 @@ typedef struct agent_arg {
 
 static void *_sig_agent(void *args)
 {
+	bool hung_pids = false;
 	agent_arg_t *agent_arg_ptr = args;
 
 	while (1) {
 		pid_t *pids = NULL;
-		int i, npids = 0, hung_pids = 0;
+		int i, npids = 0;
 		char *stat_fname = NULL;
 
+		if (hung_pids)
+			sleep(5);
+
+		hung_pids = false;
+
 		if (proctrack_g_get_pids(agent_arg_ptr->cont_id, &pids,
 					     &npids) == SLURM_SUCCESS) {
-			hung_pids = 0;
+			/*
+			 * Check if any processes are core dumping.
+			 * If so, do not signal any of them, instead
+			 * jump back to the sleep and wait for the core
+			 * dump to finish.
+			 *
+			 * This works around an issue with OpenMP
+			 * applications failing to write a full core
+			 * file out - only one of the processes will
+			 * be marked are core dumping, but killing any
+			 * of them will terminate the application.
+			 */
 			for (i = 0; i < npids; i++) {
 				xstrfmtcat(stat_fname, "/proc/%d/stat",
 					   (int) pids[i]);
 				if (_test_core_dumping(stat_fname)) {
-					debug("Process %d continuing "
-					      "core dump",
+					debug("Process %d continuing core dump",
 					      (int) pids[i]);
-					hung_pids++;
-				} else {
-					/* Kill processes that we can now */
-					kill(pids[i], agent_arg_ptr->signal);
+					hung_pids = true;
+					xfree(stat_fname);
+					break;
 				}
 				xfree(stat_fname);
 			}
+
+			if (hung_pids) {
+				xfree(pids);
+				continue;
+			}
+
+			for (i = 0; i < npids; i++) {
+				/* Kill processes */
+				kill(pids[i], agent_arg_ptr->signal);
+			}
+			xfree(pids);
 		}
-		if (hung_pids == 0)
-			break;
-		sleep(5);
+
+		break;
 	}
 
 	(void) (*(ops.signal)) (agent_arg_ptr->cont_id, agent_arg_ptr->signal);
@@ -340,7 +365,7 @@ static void _spawn_signal_thread(uint64_t cont_id, int signal)
  * signal IN  - signal to send, if zero then perform error checking
  *              but do not send signal
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
  */
 extern int proctrack_g_signal(uint64_t cont_id, int signal)
 {
@@ -395,7 +420,7 @@ extern int proctrack_g_signal(uint64_t cont_id, int signal)
  * Destroy a container, any processes within the container are not effected
  * cont_id IN - container ID as returned by proctrack_g_create()
  *
- * Returns a SLURM errno.
+ * Returns a Slurm errno.
 */
 extern int proctrack_g_destroy(uint64_t cont_id)
 {
